{********************************
 *   Rem Space Battle game v010 *
 ********************************


}

CON

  _clkmode = xtal1 + pll8x  ' ?
  _xinfreq = 10_000_000 + 0_000 ' Set to 10Mhz and add 5000 to fix crystal imperfection of hydra prototype
 _stack = ($300 - 200) >> 2             'accomodate display memory and stack

  x_tiles = 16 ' Number of horizontal tiles (each tile is 16x16), so this means 256 pixel
  y_tiles = 12 ' Number of vertical tiles, this means 192 pixel. Resolution is 256x192.

  paramcount = 14
  SCANLINE_BUFFER = $7F00

  NES_RIGHT  = %00000001
  NES_LEFT   = %00000010
  NES_DOWN   = %00000100
  NES_UP     = %00001000
  NES_START  = %00010000
  NES_SELECT = %00100000
  NES_B      = %01000000
  NES_A      = %10000000

VAR
  long tv_status      '0/1/2 = off/visible/invisible           read-only
  long tv_enable      '0/? = off/on                            write-only
  long tv_pins        '%ppmmm = pins                           write-only
  long tv_mode        '%ccinp = chroma,interlace,ntsc/pal,swap write-only
  long tv_screen      'pointer to screen (words)               write-only
  long tv_colors      'pointer to colors (longs)               write-only               
  long tv_hc          'horizontal cells                        write-only
  long tv_vc          'vertical cells                          write-only
  long tv_hx          'horizontal cell expansion               write-only
  long tv_vx          'vertical cell expansion                 write-only
  long tv_ho          'horizontal offset                       write-only
  long tv_vo          'vertical offset                         write-only
  long tv_broadcast   'broadcast frequency (Hz)                write-only
  long tv_auralcog    'aural fm cog                            write-only

  ' param for rem_engine:
  long tilemap_adr
  long tiles_adr
  long tv_status_adr
  long colors_adr
  long gamepad
  long cog_number
  long cog_total
  
  long colors[64]
  word screen[x_tiles * y_tiles]

  long temp1
  long temp2
  byte previous
  byte tile
  long framecount

OBJ

  tv    : "rem_tv_010.spin"
  rem   : "rem_spacebattle_asm_010.spin"
  rem2  : "rem_spacebattle_asm_010.spin"


PUB start      | i, j, k, kk, dx, dy, pp, pq, rr, numx, numchr
  DIRA[0] := 1
  outa[0] := 0

  longfill(@colors, $02020202, 1)

  'start tv
  longmove(@tv_status, @tvparams, paramcount)
  tv_colors := @colors
  tv.start(@tv_status)

  'init tile screen
  ' screen is defined as a 2D array of tile(x,y), each value being a 10-bit memory address divided by 64 (>>6)
  ' (each tile using 16x16x2bpp = 64 bytes per tile)
  ' and a color-table entry from 0..63 shifted by <<10

  repeat dx from 0 to x_tiles * y_tiles
    screen[dx] := SCANLINE_BUFFER >> 6 + dx

  repeat dx from 0 to 255
    byte[SCANLINE_BUFFER][dx] := $0C + ((dx & $F) << 4)

  ' perform a delay before setting the colors, this prevent a flickering screen
  ' when TV sync with signal
  repeat 160000

  tilemap_adr := @tilemap
  tiles_adr := @tile000
  tv_status_adr := @tv_status
  colors_adr := @colors
  cog_number := 0
  cog_total := 2
  rem.start(@tilemap_adr)
  repeat 10000 ' Allow each time for first cog to boot up before setting 'cog_number' again
  cog_number := 1
  rem2.start(@tilemap_adr)

  ' Start of main loop here
  repeat
    gamepad := NES_Read_Gamepad

    repeat while tv_status == 1

    repeat
      {temp1 := long[SCANLINE_BUFFER-4]
      if(temp1 == 100)
        byte[SCANLINE_BUFFER][40] := $07
      else
        byte[SCANLINE_BUFFER][40] := $02}
    while tv_status == 2

'end of main
'---------------------------------------------

PUB NES_Read_Gamepad : nes_bits   |       i

DIRA [3] := 1 ' output
DIRA [4] := 1 ' output
DIRA [5] := 0 ' input
DIRA [6] := 0 ' input

OUTA [3] := 0 ' JOY_CLK = 0
OUTA [4] := 0 ' JOY_SH/LDn = 0
OUTA [4] := 1 ' JOY_SH/LDn = 1
OUTA [4] := 0 ' JOY_SH/LDn = 0
nes_bits := 0
nes_bits := INA[5] | (INA[6] << 8)

repeat i from 0 to 6
  OUTA [3] := 1 ' JOY_CLK = 1
  OUTA [3] := 0 ' JOY_CLK = 0
  nes_bits := (nes_bits << 1)
  nes_bits := nes_bits | INA[5] | (INA[6] << 8)

nes_bits := (!nes_bits & $FFFF)
' End NES Game Paddle Read
' //////////////////////////////////////////////////////////////////       


DAT

tvparams                long    0               'status
                        long    1               'enable
                        long    %011_0000       'pins
                        long    %0000           'mode
                        long    0               'screen
                        long    0               'colors
                        long    x_tiles         'hc
                        long    y_tiles         'vc
                        long    10              'hx
                        long    1               'vx
                        long    0               'ho
                        long    0               'vo
                        long    60_000_000'_xinfreq<<4  'broadcast
                        long    0               'auralcog

tilemap                 byte $1,$2,$3,$4

tile000 byte $02,$5A,$02,$02,$02,$02,$02,$02,$4A,$3A,$5A,$02,$3A,$3A,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$6A,$4A,$02,$6A,$02,$6A,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$5A,$4A,$02,$02,$02,$02
        byte $02,$02,$02,$5A,$02,$02,$4A,$02,$02,$6A,$02,$6A,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$03,$4B,$3A,$4A,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$5B,$5B,$02,$02,$02,$6A,$02,$02,$02
        byte $02,$02,$02,$02,$8A,$02,$8D,$5C,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$5A,$02,$02,$6A,$02,$02,$03,$6B,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$8A,$5A,$02,$6A,$02,$02,$02,$02,$02,$02
        byte $5A,$6A,$4A,$02,$02,$02,$8A,$03,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$4A,$4A,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$4A,$5A,$02,$7A,$02,$02,$02,$02,$6A,$02,$02,$02
        byte $4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02
        byte $02,$02,$02,$02,$02,$7A,$03,$02,$4A,$4A,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$6A,$4A,$4A,$4A,$6A,$02,$02,$02,$02,$02,$02
tile001 byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$6A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$3A,$6A,$02,$02
tile002 byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$3A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4A,$3A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$3A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$3A,$5B,$3A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$4A,$4A,$5B,$3A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$6A,$02,$5A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
tile003 byte $02,$02,$4A,$4A,$02,$02,$02,$02,$6A,$3A,$02,$02,$02,$6A,$02,$02
        byte $02,$02,$02,$6A,$02,$4A,$6A,$02,$4A,$4A,$4A,$02,$02,$02,$02,$02
        byte $02,$02,$6A,$02,$4A,$4A,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$4A
        byte $02,$02,$02,$4A,$02,$4A,$4A,$4A,$02,$4A,$4A,$02,$02,$02,$6A,$4A
        byte $02,$02,$02,$02,$6A,$4A,$02,$02,$4A,$02,$6A,$3A,$02,$02,$02,$5A
        byte $02,$6A,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$02,$6A,$02,$02
        byte $02,$02,$02,$02,$02,$02,$6A,$02,$02,$4A,$02,$02,$4A,$02,$4A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$4A,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$02,$02,$4A,$5A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$4A
        byte $02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$4A,$02
        byte $4A,$4A,$02,$02,$02,$02,$4A,$4A,$02,$4A,$02,$4A,$02,$02,$4A,$4A
        byte $4A,$02,$02,$4A,$4A,$02,$02,$02,$3A,$3A,$3A,$3A,$4A,$4A,$4A,$4A
        byte $02,$02,$02,$4A,$02,$02,$02,$4A,$02,$3A,$3A,$3A,$4A,$02,$02,$4A
        byte $6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$3A,$6A,$4A,$3A,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$4A,$4A,$3A,$3A,$4A
tile004 byte $02,$02,$02,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$4A,$4A
        byte $02,$4A,$4A,$6A,$02,$02,$02,$4A,$02,$02,$02,$4A,$02,$4A,$4A,$4A
        byte $3A,$3A,$6A,$02,$4A,$4A,$02,$02,$02,$4A,$02,$6A,$02,$3A,$4A,$4A
        byte $3A,$4A,$02,$02,$6A,$4A,$4A,$02,$02,$02,$4A,$02,$4A,$4A,$4A,$02
        byte $4A,$6A,$4A,$02,$02,$02,$4A,$02,$4A,$02,$4A,$4A,$4A,$3A,$3A,$3A
        byte $4A,$4A,$02,$02,$4A,$02,$02,$6A,$4A,$4A,$4A,$02,$5A,$3A,$4A,$6A
        byte $4A,$02,$4A,$3A,$4A,$6A,$4A,$02,$02,$02,$02,$4A,$4A,$6A,$4A,$4A
        byte $3A,$4A,$02,$4A,$6A,$02,$4A,$4A,$4A,$6A,$4A,$02,$02,$4A,$4A,$4A
        byte $4A,$4A,$4A,$3A,$02,$02,$02,$02,$02,$4A,$02,$6A,$4A,$4A,$4A,$3A
        byte $6A,$4A,$4A,$4A,$4A,$02,$02,$02,$4A,$02,$4A,$02,$4A,$02,$02,$6A
        byte $4A,$4A,$6A,$02,$02,$02,$4A,$02,$4A,$4A,$4A,$3A,$4A,$02,$4A,$4A
        byte $4A,$02,$3A,$4A,$4A,$02,$4A,$4A,$02,$3A,$4A,$4A,$4A,$4A,$02,$4A
        byte $4A,$4A,$4A,$4A,$4A,$4A,$3A,$3A,$3A,$4A,$02,$4A,$02,$4A,$4A,$02
        byte $02,$4A,$02,$4A,$4A,$3A,$3A,$3A,$4A,$3A,$4A,$02,$02,$02,$4A,$02
        byte $4A,$4A,$4A,$3A,$03,$03,$03,$4A,$6A,$02,$4A,$4A,$02,$4A,$02,$4A
        byte $4A,$3A,$4A,$5B,$5B,$5B,$03,$3A,$4A,$6A,$4A,$4A,$4A,$4A,$03,$5D
tile005 byte $4A,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$4A,$6A,$02,$4A,$02,$02
        byte $02,$02,$6A,$02,$4A,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$6A,$02
        byte $02,$02,$02,$02,$02,$6A,$02,$4A,$02,$02,$4A,$02,$6A,$4A,$4A,$02
        byte $02,$02,$02,$4A,$02,$02,$4A,$02,$02,$6A,$4A,$02,$02,$6A,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$6A,$4A
        byte $5A,$4A,$02,$02,$02,$02,$02,$02,$4A,$02,$4A,$02,$02,$4A,$4A,$02
        byte $3A,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$4A,$3A,$4A,$02,$4A
        byte $3A,$3A,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$4A,$4A,$02,$02,$4A
        byte $4A,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$6A,$4A,$02,$02,$02
        byte $5A,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$4A,$02,$4A,$02,$02
        byte $4A,$02,$02,$02,$02,$4A,$02,$4A,$02,$02,$4A,$02,$4A,$4A,$02,$02
        byte $02,$02,$02,$4A,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$4A,$02,$02
        byte $4A,$02,$02,$02,$02,$4A,$4A,$02,$02,$4A,$4A,$02,$4A,$4A,$4A,$3A
        byte $02,$02,$3A,$3A,$3A,$3A,$3A,$3A,$03,$03,$5B,$4B,$4B,$4B,$4B,$04
        byte $03,$04,$04,$5C,$05,$DE,$8E,$06,$06,$06,$06,$06,$07,$07,$06,$07
        byte $DE,$5E,$EE,$BE,$05,$05,$05,$5D,$1D,$04,$04,$5B,$03,$03,$4A,$03
tile006 byte $02,$02,$4A,$4A,$02,$4A,$02,$3A,$03,$02,$02,$4A,$02,$02,$6A,$02
        byte $4A,$02,$02,$02,$02,$6A,$02,$4A,$2A,$3A,$02,$6A,$02,$4A,$02,$02
        byte $02,$02,$3A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$4A
        byte $02,$02,$4A,$02,$4A,$02,$02,$02,$02,$02,$4A,$02,$3A,$4A,$02,$02
        byte $3A,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$4A,$02,$4A,$02,$4A
        byte $02,$02,$02,$4A,$02,$02,$02,$4A,$02,$02,$4A,$6A,$4A,$02,$4A,$02
        byte $02,$4A,$4A,$02,$02,$4A,$02,$02,$02,$4A,$02,$02,$4A,$4A,$02,$02
        byte $02,$02,$02,$4A,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$4A,$02
        byte $02,$02,$4A,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$4A,$02,$02,$4A
        byte $6A,$02,$4A,$02,$02,$02,$4A,$02,$02,$02,$02,$4A,$02,$4A,$4A,$4A
        byte $02,$4A,$02,$4A,$02,$02,$02,$4A,$02,$4A,$4A,$02,$4A,$02,$02,$4A
        byte $02,$02,$4A,$02,$02,$4A,$02,$02,$02,$02,$4A,$4A,$02,$02,$4A,$02
        byte $3A,$3A,$4A,$3A,$4A,$3A,$3A,$3A,$2A,$2A,$03,$2A,$4B,$2A,$4B,$3B
        byte $04,$04,$04,$5D,$1D,$DD,$5D,$CD,$CD,$5D,$DD,$05,$05,$05,$DD,$DD
        byte $06,$06,$0E,$EE,$05,$5D,$5C,$04,$04,$5B,$5C,$4B,$03,$2A,$03,$03
        byte $3A,$3A,$4A,$4A,$3A,$4A,$5A,$6A,$02,$7A,$4A,$02,$4A,$02,$02,$02
tile007 byte $4A,$02,$4A,$02,$4A,$4A,$02,$02,$02,$02,$4A,$5A,$4A,$5A,$4A,$4A
        byte $02,$02,$02,$02,$02,$6A,$02,$02,$4A,$4A,$02,$6A,$4A,$4A,$6A,$3A
        byte $02,$6A,$4A,$02,$4A,$02,$02,$4A,$02,$02,$3A,$4A,$02,$4A,$02,$02
        byte $02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$4A,$4A,$4A,$4A,$4A,$4A
        byte $02,$02,$02,$4A,$02,$02,$4A,$02,$02,$4A,$02,$02,$4A,$4A,$02,$4A
        byte $02,$4A,$02,$4A,$02,$4A,$02,$02,$02,$02,$02,$4A,$4A,$02,$3A,$02
        byte $3A,$02,$02,$3A,$4A,$02,$02,$02,$4A,$3A,$4A,$02,$02,$02,$4A,$4A
        byte $3A,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$4A,$02,$4A,$02,$4A
        byte $02,$3A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$4A,$4A
        byte $02,$4A,$02,$02,$02,$4A,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02
        byte $4A,$02,$02,$02,$4A,$02,$02,$3A,$02,$4A,$02,$02,$02,$4A,$02,$02
        byte $4A,$4A,$02,$02,$4A,$4A,$4A,$02,$02,$02,$4A,$02,$02,$4A,$02,$02
        byte $03,$4B,$4B,$4B,$4B,$4B,$4B,$4B,$4B,$3A,$02,$02,$4A,$02,$3A,$02
        byte $7E,$ED,$05,$DD,$05,$DD,$05,$1D,$04,$4B,$2A,$3A,$02,$02,$02,$02
        byte $03,$03,$03,$03,$03,$5B,$03,$CD,$07,$DD,$2A,$4C,$4A,$02,$4A,$02
        byte $4A,$02,$02,$02,$4A,$02,$4A,$02,$4B,$06,$CC,$4B,$2D,$3A,$02,$02
tile008 byte $4A,$4A,$3A,$03,$3A,$3A,$02,$4A,$2A,$03,$03,$05,$06,$4E,$5E,$05
        byte $02,$6A,$4A,$3A,$3A,$4A,$4A,$3A,$5A,$03,$3A,$5D,$8E,$6E,$3E,$8D
        byte $3A,$4A,$4A,$3A,$3A,$02,$3A,$4A,$3A,$03,$5B,$5B,$04,$5D,$06,$8C
        byte $02,$4A,$4A,$4A,$03,$3A,$4A,$4A,$3A,$3A,$04,$04,$04,$04,$5B,$03
        byte $4A,$4A,$3A,$3A,$3A,$3A,$02,$02,$02,$4A,$3B,$4B,$03,$03,$4A,$5A
        byte $6A,$4A,$5A,$4A,$4A,$4A,$02,$3A,$3A,$3A,$03,$5A,$5A,$5A,$4A,$4A
        byte $4A,$4A,$02,$4A,$02,$02,$3A,$02,$2A,$03,$03,$5A,$4A,$3A,$4A,$4A
        byte $02,$3A,$3A,$02,$3A,$02,$02,$3A,$4A,$3A,$4A,$03,$3A,$4A,$4A,$4A
        byte $4A,$4A,$3A,$4A,$02,$02,$3A,$02,$02,$02,$4A,$4A,$4B,$03,$4A,$02
        byte $02,$4A,$02,$02,$4A,$3A,$02,$3A,$3A,$3A,$02,$4A,$4A,$3A,$4A,$4A
        byte $3A,$4A,$02,$4A,$4A,$4A,$3A,$02,$3A,$4A,$02,$02,$3A,$3A,$02,$4A
        byte $4A,$4A,$4A,$02,$4A,$02,$4A,$02,$4A,$02,$3A,$02,$3A,$3A,$4A,$02
        byte $02,$02,$02,$4A,$4A,$02,$02,$4A,$4A,$02,$4A,$3A,$02,$4A,$02,$4A
        byte $02,$4A,$4A,$4A,$02,$02,$4A,$4A,$02,$4A,$3A,$02,$4A,$4A,$3A,$02
        byte $4A,$02,$02,$02,$02,$4A,$02,$02,$3A,$4A,$4A,$3A,$3A,$4A,$02,$4A
        byte $02,$02,$4A,$02,$02,$02,$3A,$4A,$02,$4A,$02,$3A,$4A,$4A,$4A,$4A
tile009 byte $6E,$5C,$4D,$5E,$4D,$4D,$06,$3E,$3B,$06,$07,$07,$5E,$6E,$5E,$9E
        byte $04,$04,$5D,$05,$5C,$4C,$5E,$5C,$3C,$06,$07,$06,$6E,$8D,$7D,$8D
        byte $5B,$5B,$5D,$4B,$7D,$5C,$5D,$3E,$07,$07,$5C,$6E,$6E,$BD,$8D,$7D
        byte $5B,$03,$03,$5C,$5B,$03,$5B,$5C,$3E,$5D,$5C,$04,$5C,$7D,$AE,$9D
        byte $4A,$02,$3A,$3A,$3A,$4B,$03,$5B,$04,$7D,$8D,$5B,$8B,$7D,$7D,$7D
        byte $4A,$3A,$4A,$4A,$5A,$5A,$5B,$5C,$5B,$04,$5D,$04,$8C,$7D,$8C,$7D
        byte $4A,$6A,$02,$3A,$03,$3A,$03,$03,$03,$5C,$03,$5B,$6D,$8D,$7D,$AE
        byte $4A,$02,$3A,$4A,$4A,$4A,$5B,$03,$3A,$5B,$3A,$03,$6D,$9D,$7C,$7D
        byte $4A,$02,$4A,$5A,$5A,$5B,$03,$5A,$4A,$3A,$3A,$03,$04,$8C,$9C,$8D
        byte $02,$4A,$4A,$4A,$4A,$4A,$4A,$4A,$4A,$5A,$4A,$3A,$7B,$7D,$04,$7D
        byte $4A,$4A,$4A,$4A,$4A,$4A,$4A,$03,$5A,$4A,$5B,$5B,$5B,$7C,$9C,$5C
        byte $4A,$02,$4A,$5A,$5A,$6A,$4A,$6A,$4A,$6A,$5A,$03,$5B,$5B,$5B,$04
        byte $4A,$4A,$6A,$4A,$4A,$4A,$02,$02,$02,$4A,$4A,$4A,$3A,$5A,$03,$7C
        byte $4A,$4A,$02,$02,$4A,$02,$4A,$3A,$03,$4A,$4A,$4A,$4A,$7B,$03,$5B
        byte $4A,$02,$4A,$4A,$02,$4A,$4A,$4A,$03,$4A,$5A,$5A,$4A,$03,$03,$3A
        byte $4A,$4A,$02,$4A,$02,$02,$02,$02,$4A,$6A,$6A,$4A,$3A,$4A,$5A,$3A
tile010 byte $02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$6A,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$6A,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$4A,$02,$02,$02,$4A,$6A,$02,$02,$02,$02,$02,$02,$02,$02
        byte $03,$4A,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$5A,$02,$02,$02,$02
tile011 byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$6A
        byte $02,$02,$02,$02,$02,$02,$6A,$5A,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$4A,$4A,$3A,$4A,$02,$02,$02,$02,$02,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$6A
        byte $02,$02,$02,$02,$02,$6A,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$5A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$6A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$6A,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$7A,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02
tile012 byte $6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$6A,$02,$4A,$3A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$6A,$6A,$3A,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
tile013 byte $6A,$02,$02,$02,$02,$02,$4A,$4A,$02,$4A,$02,$03,$5B,$5B,$5B,$03
        byte $02,$02,$02,$02,$02,$02,$02,$02,$4A,$3A,$3A,$03,$5B,$04,$04,$04
        byte $02,$02,$02,$02,$02,$02,$02,$02,$4A,$4A,$4A,$03,$04,$AD,$AE,$06
        byte $02,$02,$02,$02,$02,$4A,$02,$02,$4A,$4A,$5D,$06,$07,$07,$07,$07
        byte $02,$02,$02,$02,$02,$6A,$4A,$02,$03,$07,$07,$07,$07,$07,$07,$07
        byte $02,$02,$02,$02,$02,$02,$4A,$3A,$07,$07,$04,$05,$06,$06,$07,$07
        byte $02,$02,$02,$4A,$02,$4A,$02,$5D,$07,$2A,$5C,$5D,$1D,$5D,$FE,$5E
        byte $4A,$6A,$02,$02,$02,$02,$4A,$07,$5C,$2A,$1D,$1D,$5C,$05,$5D,$1D
        byte $02,$02,$4A,$02,$4A,$02,$04,$07,$3A,$5C,$06,$3E,$1D,$05,$1D,$4C
        byte $02,$02,$02,$02,$02,$4A,$06,$06,$2A,$5C,$2E,$5D,$5C,$5D,$3D,$4C
        byte $02,$02,$02,$02,$4A,$3A,$07,$3E,$3B,$1D,$4C,$04,$4C,$4B,$4B,$4C
        byte $02,$02,$02,$02,$02,$4B,$07,$2D,$4B,$4C,$4C,$4C,$4C,$4C,$4C,$4B
        byte $02,$02,$02,$4A,$02,$5C,$07,$2A,$4C,$1D,$04,$4C,$4C,$4B,$4C,$4B
        byte $02,$4A,$02,$4A,$02,$06,$2E,$2A,$5C,$4C,$4C,$4C,$4B,$4C,$4B,$4C
        byte $02,$4A,$4A,$02,$03,$07,$3B,$4B,$4C,$4C,$4B,$4C,$4C,$4C,$4C,$4B
        byte $02,$02,$02,$02,$2E,$07,$3A,$4C,$04,$4C,$4C,$04,$4C,$4B,$4C,$4C
tile014 byte $5B,$03,$5B,$04,$4B,$5B,$03,$4A,$4A,$4A,$4A,$3A,$02,$04,$07,$1D
        byte $04,$04,$AD,$04,$04,$5B,$2A,$03,$03,$03,$03,$03,$04,$06,$4B,$8A
        byte $06,$06,$07,$06,$0E,$4E,$4E,$FE,$06,$07,$07,$07,$07,$07,$07,$07
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$06,$07,$8E,$5E,$05,$5D
        byte $07,$07,$07,$0E,$05,$5D,$1D,$4C,$5C,$4C,$5C,$0E,$5C,$04,$5C,$4C
        byte $05,$7E,$EE,$5D,$2D,$4C,$5C,$4C,$4C,$4B,$2E,$0E,$4C,$4C,$4C,$4C
        byte $5C,$1D,$5D,$5D,$1D,$4C,$04,$4C,$4C,$4B,$2E,$2E,$4B,$4C,$4B,$4C
        byte $4C,$04,$4C,$1D,$4C,$4C,$4C,$04,$4C,$4B,$3E,$2E,$4B,$4C,$4C,$04
        byte $4B,$4C,$4C,$4C,$4C,$04,$4C,$4C,$4C,$04,$0E,$1D,$4C,$4C,$4B,$4B
        byte $4C,$4B,$4C,$04,$4C,$04,$2C,$04,$2B,$04,$4E,$3D,$4B,$4C,$4C,$2D
        byte $4C,$4B,$4C,$4C,$4C,$4C,$4C,$1D,$4C,$4C,$06,$4C,$4C,$FB,$4D,$5D
        byte $4C,$4B,$4C,$4B,$4B,$4C,$04,$4C,$04,$4C,$06,$4B,$4C,$5C,$4E,$1D
        byte $4C,$4B,$4C,$4C,$4C,$4B,$4C,$4C,$4C,$1D,$0E,$4C,$4B,$4C,$06,$05
        byte $4C,$4C,$4B,$4C,$04,$4C,$4C,$4B,$04,$5D,$4E,$4B,$1D,$DD,$06,$5E
        byte $4B,$4C,$4C,$4C,$1D,$1D,$4C,$1D,$1D,$05,$2E,$4C,$5C,$1D,$06,$05
tile015 byte $4A,$4A,$5A,$4A,$02,$4A,$02,$02,$02,$4A,$02,$4A,$4A,$02,$4A,$02
        byte $03,$03,$2A,$03,$2A,$5B,$5B,$5B,$04,$04,$04,$04,$04,$04,$04,$1D
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$06,$07,$06,$07,$06,$06,$0E
        byte $4D,$3D,$3D,$4C,$04,$5C,$4B,$04,$4B,$4B,$4C,$4B,$3B,$4C,$4C,$4B
        byte $04,$4C,$04,$04,$4C,$4B,$4C,$4C,$4C,$4C,$4B,$4C,$4C,$4C,$4B,$4C
        byte $4C,$04,$4C,$4C,$4B,$4C,$4B,$4B,$4B,$4C,$4C,$4B,$04,$4C,$4C,$4B
        byte $4C,$4C,$4B,$4C,$4C,$4C,$4C,$4C,$4C,$3B,$4C,$4C,$4B,$4C,$FB,$4C
        byte $FB,$4C,$4C,$4B,$2B,$4C,$4B,$1C,$4C,$04,$3B,$4C,$4C,$04,$4C,$4C
        byte $4C,$4C,$04,$4C,$1D,$04,$4C,$4C,$4B,$4C,$2C,$04,$4C,$1D,$4B,$4C
        byte $4C,$04,$4C,$4C,$04,$4C,$4C,$04,$4C,$4C,$04,$4C,$1D,$4C,$1D,$4C
        byte $1D,$4C,$4C,$1D,$4C,$1D,$1D,$1D,$1D,$04,$2C,$04,$4C,$04,$4C,$04
        byte $05,$05,$1D,$05,$1D,$5C,$05,$5D,$5D,$1D,$4B,$4C,$4C,$4C,$4B,$4C
        byte $4E,$2E,$05,$1E,$5D,$05,$FE,$4D,$2E,$4C,$4C,$FB,$4C,$4B,$4C,$4C
        byte $07,$4E,$FE,$06,$1D,$4E,$06,$5E,$4D,$04,$4B,$4C,$4B,$4C,$4C,$4B
        byte $06,$EE,$5E,$4E,$CD,$05,$5E,$05,$4D,$4C,$4C,$4C,$4C,$3B,$4C,$4C
tile016 byte $4A,$4A,$02,$02,$5A,$02,$4A,$4A,$4A,$02,$4A,$4A,$02,$02,$02,$02
        byte $5C,$04,$5D,$CD,$BD,$BE,$8E,$8E,$EE,$04,$4A,$02,$02,$02,$02,$02
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$03,$02,$02,$02,$02
        byte $06,$FE,$8E,$FE,$8E,$4E,$4E,$FE,$06,$07,$07,$DE,$02,$02,$02,$02
        byte $4B,$4C,$4C,$04,$4C,$4B,$5C,$4C,$5C,$1D,$07,$06,$02,$02,$02,$02
        byte $4C,$4B,$4B,$4C,$4B,$4C,$4B,$4C,$04,$5C,$07,$07,$02,$02,$02,$02
        byte $4B,$4C,$4B,$4B,$4C,$4B,$4C,$4C,$4B,$4C,$07,$06,$02,$02,$4A,$02
        byte $4B,$4C,$4C,$2B,$4B,$4C,$1C,$4B,$4C,$04,$07,$06,$3A,$3A,$3A,$3A
        byte $4B,$2B,$4B,$4B,$4C,$4B,$4B,$4C,$4C,$3D,$07,$06,$03,$4B,$5B,$2A
        byte $4B,$4C,$04,$4C,$FB,$4C,$4C,$04,$4C,$1D,$07,$06,$4B,$4B,$03,$4B
        byte $4C,$4C,$4B,$4C,$1D,$5C,$0D,$1D,$5C,$4D,$07,$06,$5D,$DC,$4B,$1D
        byte $1D,$4C,$1D,$05,$5D,$5D,$4E,$05,$04,$0D,$07,$07,$05,$05,$04,$05
        byte $5C,$1D,$4E,$FE,$1D,$05,$0E,$04,$4B,$0E,$07,$07,$07,$06,$CD,$07
        byte $4B,$1D,$5E,$06,$05,$5D,$4B,$4B,$5C,$4E,$07,$06,$05,$04,$5B,$1D
        byte $4C,$5C,$0E,$5D,$04,$04,$5B,$4B,$4C,$1D,$07,$3E,$4A,$3A,$4A,$7A
        byte $3B,$1D,$04,$5B,$5B,$3B,$04,$04,$4C,$05,$07,$4E,$04,$04,$03,$1D
tile017 byte $02,$02,$02,$02,$02,$02,$02,$02,$7A,$03,$07,$04,$3B,$4D,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$1D,$06,$3A,$1D,$2A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$FE,$5B,$4B,$4D,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$5D,$CC,$2A,$3E,$03
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$04,$CD,$4A,$4D,$4B
        byte $02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$04,$AE,$4A,$2D,$04
        byte $02,$02,$02,$02,$02,$02,$4A,$02,$4A,$02,$02,$04,$8E,$03,$4C,$5C
        byte $3A,$3A,$2A,$03,$3A,$3A,$02,$3A,$02,$3A,$02,$04,$06,$5A,$4B,$5C
        byte $03,$2A,$03,$2A,$3A,$3A,$02,$4A,$3A,$3A,$3A,$04,$8E,$5A,$4C,$04
        byte $04,$4B,$04,$03,$4A,$02,$3A,$4B,$04,$04,$04,$1D,$06,$EA,$4B,$5C
        byte $CD,$04,$DD,$4B,$02,$02,$02,$05,$06,$EE,$5E,$8D,$8E,$8A,$4B,$4C
        byte $6E,$5C,$EE,$03,$02,$02,$3A,$FE,$06,$06,$06,$8E,$06,$4A,$4B,$4C
        byte $06,$CD,$06,$5B,$02,$02,$4A,$07,$06,$06,$07,$06,$8E,$03,$EA,$EA
        byte $04,$03,$4B,$4A,$02,$02,$3A,$07,$06,$06,$07,$FE,$06,$9A,$BB,$DB
        byte $4A,$4A,$02,$02,$02,$02,$3A,$07,$06,$06,$07,$8E,$06,$BA,$CC,$BC
        byte $04,$5B,$04,$02,$02,$4A,$EA,$07,$06,$06,$07,$05,$4A,$CA,$DA,$DA
tile018 byte $02,$02,$02,$02,$4A,$02,$02,$02,$4A,$02,$3A,$02,$02,$4A,$4A,$4A
        byte $02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$4A,$02,$4A,$4A,$02
        byte $02,$02,$02,$02,$3A,$3A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A
        byte $02,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$4A,$02,$02,$02,$4A,$02
        byte $02,$02,$02,$4A,$4A,$02,$02,$4A,$02,$02,$02,$02,$4A,$02,$02,$02
        byte $02,$4A,$02,$4A,$02,$02,$02,$02,$02,$4A,$3A,$02,$02,$02,$4A,$02
        byte $02,$02,$4A,$02,$3A,$02,$4A,$02,$4A,$02,$02,$4A,$02,$02,$02,$02
        byte $3A,$02,$02,$3A,$02,$4A,$02,$02,$02,$3A,$02,$02,$02,$02,$02,$02
        byte $3A,$4A,$3A,$02,$02,$02,$4A,$4A,$02,$02,$4A,$02,$02,$4A,$02,$02
        byte $4B,$2A,$3A,$3A,$4B,$03,$02,$02,$02,$4A,$02,$02,$4A,$02,$02,$4A
        byte $04,$2A,$4B,$06,$07,$4B,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $2D,$3E,$06,$06,$3E,$4D,$5B,$4A,$02,$02,$02,$02,$02,$4A,$02,$02
        byte $2D,$3E,$4D,$06,$07,$06,$06,$07,$1D,$2B,$4C,$4B,$02,$02,$02,$02
        byte $1D,$4D,$06,$4D,$3D,$3D,$07,$07,$07,$07,$06,$07,$5B,$02,$4A,$02
        byte $4B,$4C,$2C,$3D,$07,$07,$3D,$4D,$4D,$4D,$3E,$07,$06,$4A,$02,$02
        byte $03,$03,$2B,$4C,$3C,$1D,$3D,$3D,$4D,$3E,$07,$3E,$04,$4A,$02,$02
tile019 byte $02,$4A,$3A,$02,$4A,$02,$4A,$02,$02,$3A,$02,$6A,$5A,$4A,$4A,$4A
        byte $02,$4A,$4A,$02,$4A,$02,$4A,$4A,$02,$6A,$4A,$4A,$4A,$02,$6A,$4A
        byte $02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$4A,$02,$4A,$4A,$3A,$4A
        byte $4A,$02,$4A,$02,$4A,$4A,$02,$02,$4A,$02,$4A,$02,$4A,$6A,$4A,$4A
        byte $02,$4A,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$4A,$02,$4A,$02,$4A
        byte $02,$02,$02,$02,$4A,$02,$4A,$02,$02,$4A,$4A,$02,$02,$02,$4A,$02
        byte $4A,$02,$02,$4A,$02,$4A,$02,$4A,$4A,$02,$02,$4A,$4A,$02,$4A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$02,$02
        byte $4A,$02,$02,$4A,$02,$02,$4A,$02,$4A,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$4A,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$4A,$02
        byte $02,$02,$02,$02,$4A,$02,$4A,$02,$4A,$02,$02,$02,$4A,$02,$02,$02
        byte $02,$4A,$02,$02,$02,$4A,$02,$02,$4A,$02,$4A,$02,$02,$02,$4A,$02
        byte $02,$02,$02,$4A,$02,$02,$4A,$4A,$02,$02,$02,$02,$4A,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$4A,$02,$02,$4A,$02,$4A,$02,$02,$02,$4A
        byte $02,$02,$02,$02,$02,$4A,$02,$4A,$02,$4A,$02,$4A,$02,$3A,$02,$02
        byte $02,$02,$4A,$02,$02,$02,$4A,$02,$02,$02,$02,$02,$4A,$02,$02,$02
tile020 byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$8A,$7A,$02,$6A,$02,$8A,$04,$02,$02,$02,$02
        byte $02,$7A,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$6A,$6A,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02
        byte $02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$6A,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$4A,$6A,$02,$02,$02,$6A,$02,$6A,$02,$02,$02,$02,$02,$02,$02
        byte $7A,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02
        byte $02,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$6A
        byte $02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02
        byte $6A,$02,$02,$02,$6A,$02,$6A,$02,$02,$02,$6A,$02,$02,$4A,$6A,$02
tile021 byte $02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$02,$02,$02,$02,$6A,$6A,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$6A,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$7A,$02,$02,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$7A,$5A,$4A,$4A,$4A,$4A
        byte $02,$02,$6A,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$04,$2A,$3A,$4A
        byte $02,$02,$02,$02,$6A,$02,$02,$02,$02,$4A,$5B,$05,$07,$07,$2E,$1D
        byte $02,$4A,$02,$6A,$02,$02,$02,$02,$02,$03,$07,$07,$06,$06,$07,$07
        byte $6A,$02,$4A,$02,$6A,$4A,$6A,$5A,$02,$BD,$07,$0E,$06,$07,$07,$07
        byte $02,$5A,$02,$4A,$4A,$6A,$02,$6A,$8A,$06,$06,$07,$07,$07,$07,$07
        byte $6A,$6A,$6A,$6A,$6A,$8A,$5A,$CA,$03,$07,$07,$07,$07,$07,$07,$07
tile022 byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$4A
        byte $7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$6A,$02,$02
        byte $5B,$5A,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$4A,$02
        byte $5B,$5A,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$4A,$02,$4A,$02
        byte $02,$02,$02,$6A,$4A,$02,$02,$02,$02,$6A,$02,$6A,$02,$02,$02,$02
        byte $02,$02,$02,$02,$4A,$6A,$02,$6A,$02,$02,$02,$4A,$02,$02,$02,$02
        byte $02,$6A,$5A,$4A,$02,$02,$02,$02,$02,$02,$6A,$4A,$02,$02,$6A,$02
        byte $4A,$5B,$5A,$6A,$6A,$02,$02,$02,$6A,$02,$4A,$02,$02,$02,$02,$02
        byte $04,$04,$4A,$4A,$02,$6A,$02,$6A,$02,$6A,$02,$02,$02,$02,$02,$03
        byte $5C,$03,$3A,$4A,$02,$4A,$02,$02,$02,$4A,$02,$02,$6A,$6A,$AA,$DA
        byte $2E,$2A,$7A,$6A,$02,$02,$6A,$4A,$3A,$03,$2A,$4B,$4B,$DA,$9B,$DA
        byte $3E,$3D,$5A,$8A,$03,$03,$5B,$03,$03,$2A,$03,$5B,$DA,$CB,$03,$DA
        byte $06,$3E,$4B,$04,$04,$3B,$EA,$3A,$4A,$5A,$EA,$DA,$9B,$AA,$9B,$9A
        byte $3D,$5C,$04,$3B,$4B,$03,$3A,$03,$5A,$4A,$5B,$AA,$CA,$5A,$5A,$8A
tile023 byte $4A,$02,$02,$4A,$07,$0E,$2A,$4C,$4C,$4B,$4C,$4C,$4C,$1D,$04,$4C
        byte $02,$02,$02,$03,$07,$4D,$4B,$5C,$4C,$4C,$4C,$4C,$4C,$04,$4C,$4C
        byte $02,$4A,$02,$04,$07,$4B,$4C,$4C,$1D,$04,$1D,$04,$1D,$1D,$1D,$1D
        byte $02,$4A,$02,$2E,$06,$3B,$1D,$2D,$3D,$3D,$3D,$4D,$05,$5E,$BE,$CE
        byte $4A,$02,$6A,$07,$0E,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $4A,$02,$04,$06,$CD,$06,$06,$06,$06,$06,$07,$07,$07,$07,$07,$07
        byte $02,$02,$EE,$DC,$04,$DC,$04,$EC,$DB,$BC,$DB,$BC,$BC,$9D,$BC,$CC
        byte $02,$4A,$04,$DA,$0D,$1D,$DA,$04,$04,$04,$1D,$04,$DC,$04,$04,$CC
        byte $02,$9A,$DA,$04,$05,$05,$4B,$04,$1D,$1D,$04,$1D,$1D,$1D,$1D,$1D
        byte $03,$DA,$04,$1D,$0D,$4D,$1D,$EB,$04,$04,$04,$DC,$04,$04,$1D,$DC
        byte $CB,$04,$1D,$0D,$4D,$1D,$4D,$04,$04,$DC,$04,$1D,$1D,$DC,$5C,$04
        byte $04,$04,$1D,$1D,$1D,$1D,$0D,$0D,$4B,$04,$04,$04,$04,$1D,$DC,$1D
        byte $04,$0D,$0D,$4D,$0D,$1D,$4D,$2E,$DD,$DA,$04,$04,$04,$04,$04,$04
        byte $04,$ED,$4D,$1D,$0D,$4D,$0D,$04,$1D,$04,$DA,$04,$1D,$4B,$4B,$04
        byte $04,$04,$0D,$0D,$4D,$2D,$2D,$0D,$1D,$1E,$1D,$04,$04,$1D,$1D,$04
        byte $CA,$4B,$04,$1D,$1D,$0D,$0D,$4D,$2D,$1D,$0D,$1D,$04,$05,$CD,$04
tile024 byte $4C,$04,$0D,$DE,$1D,$5D,$05,$1D,$04,$1D,$4D,$04,$4D,$5C,$4E,$4D
        byte $04,$4C,$3D,$04,$4B,$04,$5C,$1D,$5C,$4C,$04,$4C,$1D,$5C,$1D,$04
        byte $1D,$5C,$5C,$4C,$1D,$1D,$0D,$2E,$04,$04,$4B,$04,$5E,$DE,$04,$03
        byte $8E,$2E,$1D,$4C,$5D,$1D,$5C,$1D,$4C,$0D,$05,$2E,$04,$2A,$4B,$04
        byte $07,$07,$07,$07,$5D,$04,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $07,$07,$06,$04,$03,$5C,$4E,$0E,$06,$EE,$EE,$05,$EE,$7E,$EE,$EE
        byte $06,$06,$4A,$EA,$DA,$DB,$04,$DB,$04,$DB,$CC,$CC,$04,$DB,$04,$DB
        byte $AD,$BC,$AA,$04,$5C,$04,$CC,$04,$CC,$5C,$04,$CC,$04,$BC,$DB,$9B
        byte $DC,$CD,$EB,$9B,$DC,$5D,$1D,$1D,$DC,$1D,$DD,$CD,$04,$DA,$DA,$04
        byte $5C,$DD,$04,$04,$DA,$04,$04,$DC,$1D,$5D,$1D,$05,$DD,$04,$04,$CC
        byte $04,$04,$CD,$04,$04,$DA,$5B,$04,$1D,$DC,$1D,$CD,$0E,$8E,$06,$CD
        byte $1D,$04,$1D,$CD,$04,$1D,$CC,$04,$04,$1D,$04,$04,$4E,$07,$07,$06
        byte $5D,$1D,$04,$1D,$04,$1D,$04,$1D,$DC,$1D,$04,$EE,$07,$07,$07,$06
        byte $FA,$4B,$04,$4B,$4B,$04,$DC,$04,$1D,$04,$04,$07,$07,$07,$07,$06
        byte $4B,$03,$EA,$03,$04,$04,$04,$04,$04,$04,$EE,$07,$07,$07,$07,$07
        byte $04,$ED,$4E,$0E,$EE,$ED,$0D,$05,$DD,$05,$06,$07,$07,$07,$07,$07
tile025 byte $05,$2E,$1E,$5D,$03,$4B,$5D,$5D,$1D,$04,$4C,$04,$4C,$04,$3B,$2A
        byte $5C,$CD,$04,$5B,$4B,$5C,$DD,$5D,$1D,$4C,$4C,$1D,$4C,$04,$4B,$CD
        byte $4B,$4B,$4B,$1D,$04,$1D,$3D,$1D,$5C,$04,$2B,$04,$4B,$2D,$4B,$3A
        byte $04,$04,$2D,$3D,$1D,$1D,$5D,$1D,$1D,$4B,$04,$1D,$05,$05,$1D,$1D
        byte $07,$07,$07,$07,$07,$07,$06,$5C,$3A,$5C,$07,$07,$07,$06,$06,$07
        byte $BE,$05,$CD,$BD,$BD,$8E,$CD,$5A,$03,$CC,$CD,$CC,$04,$04,$5C,$5C
        byte $BC,$DB,$AC,$CC,$CD,$06,$5A,$CA,$04,$EB,$04,$04,$DB,$CC,$DB,$DB
        byte $04,$04,$04,$DB,$CC,$CB,$AA,$CC,$CC,$04,$DC,$DC,$04,$1D,$DC,$04
        byte $05,$DC,$1D,$5D,$5C,$CD,$DB,$03,$04,$DD,$4C,$1D,$1D,$5C,$1D,$CC
        byte $04,$04,$04,$DB,$04,$CC,$04,$04,$DA,$DA,$04,$04,$DC,$04,$04,$4B
        byte $4B,$04,$04,$04,$DA,$03,$4B,$04,$DC,$04,$04,$EC,$04,$04,$EB,$EB
        byte $FE,$2E,$1D,$5D,$DC,$04,$DC,$04,$1D,$DC,$04,$04,$04,$EB,$4B,$03
        byte $07,$07,$3E,$1D,$1D,$1D,$04,$DD,$04,$04,$04,$FB,$EA,$5B,$03,$FA
        byte $5E,$07,$06,$4E,$04,$04,$1D,$FB,$04,$FB,$EB,$03,$4B,$EA,$EA,$5B
        byte $07,$07,$07,$3E,$1D,$04,$04,$DA,$4B,$EA,$03,$FA,$03,$03,$03,$EA
        byte $07,$07,$07,$5D,$05,$FA,$DA,$5B,$EA,$5B,$EA,$5B,$EA,$4B,$04,$04
tile026 byte $05,$05,$05,$EE,$04,$04,$4C,$4C,$5C,$5D,$07,$4E,$04,$5B,$5A,$04
        byte $04,$03,$CE,$06,$04,$4C,$2B,$04,$4C,$0D,$07,$05,$03,$EA,$8A,$03
        byte $2A,$5D,$8E,$FE,$1D,$5C,$4B,$4C,$3B,$5D,$07,$5D,$02,$6A,$02,$02
        byte $1D,$EE,$06,$06,$05,$0D,$2E,$2E,$4D,$0E,$07,$04,$4A,$4A,$4A,$4A
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$04,$04,$04,$4A,$4B
        byte $CC,$CD,$DC,$CC,$04,$04,$04,$EB,$EA,$4D,$07,$04,$04,$04,$03,$04
        byte $EB,$9B,$DA,$9B,$DA,$DB,$DB,$DA,$4B,$4C,$07,$04,$1D,$04,$03,$CD
        byte $04,$04,$EB,$DA,$9B,$DB,$9B,$EA,$2A,$1D,$07,$5B,$5C,$04,$03,$5D
        byte $04,$DA,$9B,$EB,$4B,$EA,$03,$4A,$2A,$3D,$07,$03,$CD,$04,$03,$5D
        byte $DA,$4B,$04,$4B,$FA,$03,$8A,$03,$2A,$4D,$06,$03,$CD,$04,$5B,$05
        byte $5B,$FA,$03,$03,$03,$03,$4A,$03,$3B,$2E,$5E,$5B,$05,$04,$04,$DE
        byte $FA,$4B,$03,$03,$03,$5A,$5A,$03,$2A,$4E,$1D,$03,$7E,$04,$04,$CE
        byte $5B,$EA,$03,$EA,$03,$03,$03,$4B,$2B,$06,$04,$04,$9E,$04,$5C,$6E
        byte $03,$03,$03,$03,$04,$DB,$04,$04,$04,$2E,$4D,$04,$05,$04,$05,$EE
        byte $03,$DB,$04,$DB,$5B,$DA,$DA,$DA,$5B,$04,$0E,$3D,$1D,$3E,$07,$5C
        byte $DD,$5D,$DD,$CC,$CC,$04,$04,$04,$04,$2D,$3D,$4D,$3E,$3E,$5D,$5B
tile027 byte $5B,$03,$5B,$5A,$02,$3A,$03,$06,$06,$06,$07,$BD,$03,$03,$BC,$03
        byte $03,$4A,$EA,$7A,$02,$03,$03,$06,$06,$06,$06,$CE,$8E,$CB,$BC,$DA
        byte $4A,$02,$4A,$02,$02,$03,$03,$CE,$07,$06,$07,$AE,$AE,$BC,$DB,$9A
        byte $4A,$4A,$03,$03,$4A,$5B,$03,$05,$07,$06,$06,$BE,$CD,$CB,$03,$EA
        byte $DC,$04,$5D,$03,$02,$5B,$03,$05,$06,$06,$06,$AE,$CC,$DA,$AA,$03
        byte $5D,$04,$04,$03,$02,$03,$03,$CD,$07,$8E,$06,$CD,$03,$03,$EA,$5A
        byte $5D,$04,$04,$03,$02,$4B,$4B,$03,$04,$04,$04,$04,$EA,$4B,$4B,$03
        byte $CD,$04,$04,$03,$02,$03,$4B,$4A,$03,$3B,$04,$EA,$4B,$EA,$4B,$5B
        byte $CD,$4B,$04,$03,$02,$03,$04,$3A,$1D,$04,$2A,$4B,$03,$3A,$04,$04
        byte $8D,$04,$04,$03,$02,$03,$04,$2A,$04,$4B,$2B,$1D,$2C,$2D,$4D,$2D
        byte $5D,$03,$04,$4A,$02,$2A,$1D,$4B,$4B,$4C,$1D,$4D,$3E,$3E,$3E,$4B
        byte $CD,$5B,$04,$3A,$2A,$04,$2A,$4B,$2B,$4C,$4D,$2E,$3E,$06,$3D,$4B
        byte $CC,$4B,$04,$04,$4C,$2A,$4B,$4C,$2C,$2D,$3E,$3E,$3E,$3D,$2D,$4B
        byte $04,$2A,$4C,$4C,$2A,$3B,$4C,$2C,$2D,$3E,$3E,$2E,$4C,$1D,$2D,$2D
        byte $4B,$2D,$1C,$3A,$4B,$4C,$1C,$1D,$3E,$3E,$3E,$4C,$2D,$3D,$2D,$3D
        byte $2A,$5C,$03,$3B,$1D,$4C,$4C,$4D,$06,$3E,$4B,$4C,$3E,$4D,$3D,$4D
tile028 byte $4A,$03,$EA,$3A,$EA,$3A,$FA,$2C,$4D,$07,$3D,$3A,$02,$02,$4A,$02
        byte $EA,$DA,$03,$DA,$DA,$EA,$03,$3B,$4E,$4C,$02,$02,$02,$4A,$02,$02
        byte $03,$DA,$DA,$DA,$AB,$DA,$5A,$4A,$3A,$02,$3A,$4A,$4A,$02,$02,$4A
        byte $03,$DA,$9B,$DA,$CA,$CA,$02,$4A,$02,$3A,$02,$02,$3A,$4A,$4A,$02
        byte $EA,$03,$DA,$CA,$CA,$7A,$3A,$02,$02,$02,$02,$3A,$02,$02,$02,$4A
        byte $4A,$DA,$9A,$CA,$8A,$4A,$02,$02,$4A,$02,$4A,$4A,$02,$3A,$4A,$02
        byte $CA,$03,$CA,$5A,$EA,$CA,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02
        byte $5A,$02,$4A,$CA,$5A,$5A,$4A,$4A,$3A,$3A,$3A,$4A,$4A,$3A,$3A,$4A
        byte $5A,$4A,$EA,$5A,$CA,$02,$02,$4A,$3A,$4A,$2A,$3A,$03,$3B,$3B,$4C
        byte $02,$4A,$3A,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$FA,$2A
        byte $5A,$5A,$EA,$7A,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$3A,$3A,$4A
        byte $CA,$6A,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02
        byte $4A,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$3A,$02,$3A
        byte $03,$8A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$4A
        byte $04,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$3A,$02
        byte $1D,$4A,$8A,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$3A
tile029 byte $4A,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$3A,$02,$02,$02,$4A,$02,$02,$4A,$02,$02,$02,$4A,$02,$4A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02
        byte $02,$02,$02,$4A,$02,$02,$3A,$02,$4A,$02,$02,$4A,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$02,$03
        byte $02,$02,$02,$02,$3A,$02,$4A,$02,$02,$02,$02,$4A,$02,$02,$4A,$3A
        byte $4C,$3B,$3A,$02,$02,$4A,$02,$3A,$02,$02,$02,$02,$4A,$02,$4A,$4A
        byte $3A,$2A,$3A,$4A,$3A,$02,$4A,$02,$4A,$02,$02,$4A,$02,$4A,$4A,$4A
        byte $3A,$2A,$4B,$03,$4A,$4A,$4A,$02,$4A,$4A,$4A,$02,$4A,$02,$6A,$02
        byte $3A,$4B,$4C,$4B,$6A,$4A,$4A,$4A,$6A,$6A,$5A,$6A,$6A,$5A,$6A,$6A
        byte $3A,$4B,$4B,$5B,$3A,$6A,$6A,$6A,$4A,$6A,$6A,$6A,$6A,$6A,$6A,$6A
        byte $2A,$4B,$5B,$03,$03,$3A,$4A,$4A,$4A,$6A,$4A,$4A,$4A,$6A,$4A,$6A
        byte $2A,$5B,$4A,$4A,$3A,$6B,$4A,$6B,$4A,$6B,$6A,$6B,$6A,$6B,$6A,$4A
        byte $03,$03,$4A,$02,$4A,$3A,$6B,$4A,$6B,$6A,$4A,$6A,$4A,$6A,$6B,$6A
tile030 byte $7A,$02,$6A,$6A,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$4A
        byte $7A,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$6A,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$3A,$4A
        byte $7A,$02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A
        byte $02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02
        byte $02,$8A,$8A,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02
        byte $02,$5A,$8A,$02,$02,$02,$6A,$6A,$7A,$02,$02,$02,$02,$02,$6A,$02
        byte $02,$02,$6A,$02,$6A,$6A,$6A,$6A,$6A,$02,$6A,$6A,$02,$02,$6A,$5B
        byte $7A,$7A,$6A,$6A,$6A,$6A,$6A,$6A,$02,$6A,$6A,$02,$6A,$6A,$7B,$5B
        byte $7A,$5A,$7A,$7A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$5B,$03
        byte $6A,$6A,$6A,$6A,$02,$6A,$02,$6A,$6A,$6A,$6A,$6A,$6A,$7B,$5B,$03
        byte $02,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$7B,$6A,$7A,$03,$5B,$EA
        byte $6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$7B,$03,$03,$03
        byte $6A,$6A,$6A,$02,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$7A,$03,$03,$4B,$2A
        byte $7A,$6A,$7A,$7A,$6A,$6A,$6A,$6A,$6A,$6A,$7A,$7B,$5B,$03,$5B,$5C
tile031 byte $02,$02,$02,$7A,$CA,$04,$EA,$5B,$04,$06,$06,$07,$07,$07,$07,$07
        byte $02,$4A,$7A,$CA,$AC,$DB,$04,$04,$04,$06,$07,$07,$07,$07,$07,$06
        byte $4A,$6A,$CA,$BB,$BB,$BC,$BC,$CC,$BC,$DD,$07,$06,$07,$07,$06,$CE
        byte $02,$6A,$BA,$BC,$BC,$AC,$9C,$BD,$BD,$BD,$06,$06,$07,$07,$AE,$9D
        byte $6A,$02,$7A,$BB,$AC,$8C,$8C,$9D,$DE,$CD,$AD,$9E,$AE,$AD,$BC,$BC
        byte $02,$6A,$7A,$AA,$BB,$9C,$8C,$9D,$9D,$9D,$9D,$9D,$CC,$AC,$9D,$CC
        byte $02,$6A,$3A,$03,$03,$BC,$8C,$8C,$8C,$07,$07,$8C,$AC,$BC,$AE,$AE
        byte $5A,$03,$03,$03,$03,$AB,$BC,$8C,$8C,$07,$07,$AC,$AC,$9D,$9D,$BD
        byte $5A,$3A,$03,$03,$EA,$8A,$BA,$AC,$8C,$8C,$07,$9D,$AE,$8E,$BC,$CB
        byte $03,$03,$03,$3A,$5A,$5A,$CA,$BB,$8C,$8C,$07,$AE,$07,$07,$CC,$CA
        byte $3A,$03,$03,$4A,$4A,$03,$02,$02,$BA,$AC,$07,$07,$9D,$07,$AE,$9C
        byte $5B,$03,$03,$5A,$03,$03,$02,$02,$02,$BB,$8C,$07,$07,$9D,$07,$CC
        byte $5B,$3A,$4A,$4A,$4A,$7A,$02,$02,$02,$CA,$BB,$9D,$07,$07,$07,$AE
        byte $03,$03,$03,$03,$5A,$02,$02,$02,$02,$02,$AB,$9D,$9D,$07,$AD,$AE
        byte $03,$03,$4B,$03,$02,$02,$02,$02,$02,$8A,$9B,$BB,$9D,$07,$07,$07
        byte $4B,$4B,$4B,$03,$6A,$02,$02,$02,$02,$7B,$02,$02,$BA,$8C,$9D,$07
tile032 byte $03,$4B,$4B,$FA,$2A,$03,$3A,$EA,$03,$EA,$EA,$02,$7A,$8A,$9A,$EA
        byte $5B,$EA,$5B,$FA,$4B,$03,$03,$3A,$03,$5A,$6A,$8A,$5A,$CA,$CA,$9B
        byte $04,$9A,$FA,$5B,$03,$2A,$EA,$03,$5A,$CA,$8A,$CA,$AA,$AA,$03,$DA
        byte $AB,$03,$4B,$2A,$4B,$03,$03,$4A,$8A,$EA,$9B,$04,$04,$04,$04,$04
        byte $04,$5B,$FA,$5B,$2A,$03,$EA,$9A,$DB,$04,$04,$EC,$04,$0C,$EB,$04
        byte $04,$FA,$03,$5B,$DA,$03,$EB,$04,$DD,$04,$EC,$04,$04,$DB,$04,$04
        byte $CA,$3A,$03,$FA,$03,$BC,$CC,$CC,$DC,$04,$DB,$04,$DB,$04,$DB,$DB
        byte $CA,$4A,$03,$EA,$AB,$DB,$BC,$DB,$CC,$CC,$CC,$CC,$CC,$DB,$04,$DB
        byte $9B,$8A,$5A,$CB,$BC,$BB,$BC,$BC,$BC,$CC,$CC,$CC,$CC,$CC,$BC,$CC
        byte $AA,$CA,$CA,$CB,$BC,$BC,$BC,$CC,$CC,$CC,$CC,$CC,$BC,$BC,$CC,$BC
        byte $EA,$03,$BB,$BC,$9D,$DE,$CC,$CC,$CC,$CC,$CC,$CC,$CC,$CC,$BC,$CC
        byte $CA,$CB,$BB,$BB,$CC,$CC,$CC,$CC,$CC,$9D,$CC,$CC,$CC,$CC,$CC,$CC
        byte $CB,$BC,$BB,$BC,$BC,$CC,$CC,$9D,$CC,$CC,$CC,$9D,$9D,$CC,$BC,$CC
        byte $BC,$BC,$AC,$AC,$BC,$9D,$AD,$CC,$9D,$9D,$9D,$AD,$CC,$9D,$9D,$CC
        byte $9D,$BB,$AC,$AC,$8C,$9D,$07,$07,$9E,$07,$07,$07,$07,$07,$8E,$06
        byte $BC,$BC,$AC,$8C,$8C,$8C,$9D,$07,$07,$07,$07,$07,$07,$07,$07,$07
tile033 byte $9B,$DA,$DA,$EB,$04,$1D,$1D,$1D,$CD,$1D,$1D,$DD,$1D,$04,$1D,$1D
        byte $DA,$AB,$04,$04,$04,$1D,$04,$DC,$04,$04,$04,$04,$DC,$1D,$DC,$04
        byte $04,$04,$04,$04,$04,$04,$DC,$4B,$04,$0C,$04,$0C,$04,$04,$04,$0C
        byte $0C,$04,$EC,$04,$EC,$FB,$04,$EC,$04,$04,$04,$04,$EB,$04,$04,$04
        byte $04,$FB,$04,$EB,$04,$04,$4B,$EB,$04,$EB,$EB,$EB,$04,$EB,$EB,$DB
        byte $EB,$04,$EB,$04,$04,$EB,$DB,$EB,$04,$EB,$04,$04,$04,$DB,$04,$EB
        byte $04,$DB,$04,$DB,$EB,$DA,$04,$DA,$DA,$DA,$EB,$DA,$DA,$DA,$EB,$9B
        byte $DB,$DB,$DB,$04,$DB,$BC,$DB,$04,$DB,$04,$9B,$DB,$DB,$04,$DB,$EB
        byte $BC,$CC,$BC,$DB,$BC,$DB,$DB,$DB,$BC,$DB,$DB,$9B,$BC,$DB,$AB,$BC
        byte $CC,$BC,$CC,$BC,$CC,$BC,$BC,$BC,$DB,$BC,$BC,$CC,$DB,$9C,$DB,$DA
        byte $BC,$CC,$BC,$BC,$BC,$BC,$BC,$BC,$CC,$BC,$BC,$BC,$BC,$BC,$BC,$BC
        byte $BC,$CC,$BC,$CC,$CC,$BC,$CC,$BC,$CC,$BC,$CC,$BC,$BC,$BC,$BC,$BC
        byte $CC,$BC,$CC,$BC,$BC,$CC,$BC,$CC,$CC,$CC,$BC,$BC,$CC,$BC,$BC,$BC
        byte $BC,$CC,$CC,$BC,$CC,$BC,$CC,$CC,$BC,$BC,$BC,$BC,$BC,$BC,$BC,$BC
        byte $AE,$9E,$AE,$AE,$AD,$BD,$AE,$9D,$9D,$9D,$BC,$CC,$BC,$BC,$CC,$BC
        byte $07,$07,$07,$07,$07,$07,$07,$07,$AE,$07,$AE,$AE,$07,$AD,$AE,$AE
tile034 byte $1D,$1D,$1D,$1D,$1D,$1D,$1D,$1D,$DD,$1D,$06,$07,$07,$07,$06,$07
        byte $DC,$04,$DC,$04,$04,$04,$04,$DC,$04,$04,$06,$07,$06,$06,$07,$07
        byte $04,$DC,$04,$0C,$04,$EC,$04,$04,$0C,$EB,$05,$07,$4E,$07,$07,$07
        byte $EB,$04,$04,$DB,$04,$EB,$CC,$EB,$04,$DB,$DA,$06,$07,$07,$07,$07
        byte $04,$EB,$DB,$04,$DB,$04,$EB,$04,$DB,$04,$9B,$DA,$07,$07,$07,$07
        byte $04,$DA,$04,$EB,$EB,$EB,$BC,$DA,$DA,$DA,$DA,$DA,$9A,$CC,$7E,$7E
        byte $DB,$DA,$DA,$DA,$9B,$DA,$DA,$9B,$DA,$AB,$DA,$DA,$DA,$03,$EA,$9B
        byte $9B,$DB,$9B,$DB,$DB,$9B,$DA,$DA,$DA,$DA,$9A,$CA,$9A,$DA,$03,$CB
        byte $DB,$DB,$DB,$DA,$DA,$DA,$DA,$CB,$AB,$CA,$CA,$CA,$9A,$EA,$CA,$BC
        byte $DB,$9C,$DB,$BC,$BC,$CB,$9B,$BC,$DA,$CA,$CA,$AA,$CA,$CA,$BA,$BB
        byte $BC,$CB,$BC,$CB,$DB,$CB,$CB,$CA,$9D,$CA,$CA,$CA,$BA,$9A,$DA,$CC
        byte $BC,$BC,$BC,$BC,$BC,$AC,$DA,$CA,$CC,$9B,$CA,$CA,$CA,$BA,$BC,$AE
        byte $BC,$BC,$BC,$BC,$BC,$CB,$AA,$CB,$9B,$DB,$BA,$BA,$BA,$BC,$AE,$AE
        byte $BC,$BC,$BC,$BC,$BC,$AC,$CB,$DA,$DA,$AB,$CB,$CB,$BC,$AE,$9D,$07
        byte $CC,$CC,$CC,$BC,$BC,$CB,$DB,$CB,$AB,$DB,$CB,$BC,$AE,$AE,$07,$9D
        byte $9D,$9D,$9D,$BC,$BC,$BC,$CB,$DB,$CB,$AB,$AB,$AD,$AE,$07,$9D,$07
tile035 byte $07,$07,$07,$CD,$5B,$5B,$EA,$EA,$03,$EA,$03,$4B,$5D,$DD,$3B,$4B
        byte $07,$07,$07,$8D,$EA,$EA,$EA,$5B,$03,$EA,$5B,$EB,$4A,$4B,$1D,$DE
        byte $06,$07,$07,$5B,$EA,$5B,$EA,$EA,$4B,$5B,$3A,$EA,$04,$CC,$BC,$BC
        byte $06,$07,$CC,$03,$DA,$03,$5B,$4B,$EB,$DA,$DB,$CC,$CC,$BC,$BC,$BC
        byte $07,$AE,$9B,$9B,$FA,$4B,$04,$CC,$CC,$AD,$9D,$BC,$BC,$BC,$BC,$BC
        byte $AD,$DA,$04,$EA,$DA,$BC,$BC,$BC,$9D,$9D,$9D,$9D,$9D,$9D,$CC,$CC
        byte $06,$9B,$CB,$BB,$AC,$BC,$AD,$AD,$AD,$9D,$9D,$AD,$AD,$AD,$BC,$CA
        byte $9D,$BC,$9C,$8C,$07,$8C,$BC,$AE,$AD,$AE,$AE,$AD,$BC,$CA,$02,$02
        byte $AE,$9D,$9D,$8C,$07,$8C,$BB,$AD,$AE,$AE,$9D,$CB,$02,$02,$02,$02
        byte $BC,$AD,$9D,$07,$8C,$8C,$BB,$BD,$AD,$BC,$CA,$02,$02,$02,$02,$02
        byte $AE,$AE,$07,$07,$AC,$BB,$9D,$AD,$BA,$02,$02,$02,$02,$02,$02,$02
        byte $AE,$9D,$9D,$8C,$9D,$BC,$BC,$CA,$02,$02,$02,$02,$02,$02,$02,$4A
        byte $AD,$AE,$AE,$AE,$AD,$CB,$02,$7A,$02,$02,$02,$02,$02,$02,$4A,$5A
        byte $9D,$07,$AE,$9D,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$7A,$03,$4A
        byte $07,$9D,$BC,$CA,$02,$02,$02,$02,$7A,$02,$02,$02,$02,$5A,$EA,$5A
        byte $8C,$BC,$02,$02,$8A,$02,$02,$02,$02,$02,$02,$02,$02,$EA,$03,$3A
tile036 byte $4C,$2E,$05,$04,$04,$EB,$4B,$1C,$4C,$2D,$3D,$4D,$3E,$3E,$9B,$9B
        byte $DD,$CC,$DB,$DA,$DA,$EA,$03,$03,$4B,$2D,$3E,$3E,$3E,$5C,$03,$03
        byte $BC,$CB,$CB,$CB,$03,$AA,$4A,$03,$4B,$0D,$4C,$2A,$02,$02,$02,$02
        byte $BC,$BC,$BC,$CB,$DA,$03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $BC,$DB,$DA,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $CB,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$4A,$3A,$3A,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$6A,$4A,$03,$03,$3A,$3A,$2A,$2A
        byte $02,$02,$02,$02,$5A,$4A,$6A,$EA,$4A,$03,$5B,$EA,$4A,$3A,$2A,$4B
        byte $02,$02,$02,$7A,$03,$EA,$4A,$4A,$03,$03,$03,$02,$3A,$3A,$03,$03
        byte $4A,$4A,$7A,$4A,$4A,$5A,$5A,$03,$03,$03,$4A,$4A,$02,$4A,$3A,$02
        byte $5A,$4A,$02,$5A,$02,$5A,$02,$4A,$03,$EA,$02,$4A,$4A,$02,$4A,$02
        byte $5A,$8A,$5A,$4A,$4A,$5A,$5A,$03,$03,$4A,$4A,$02,$4A,$02,$4A,$03
        byte $02,$4A,$4A,$5A,$4A,$02,$4A,$4A,$4A,$02,$02,$4A,$02,$4A,$5B,$03
        byte $03,$4A,$4A,$4A,$5A,$4A,$4A,$02,$02,$4A,$02,$02,$4A,$5A,$02,$02
        byte $03,$4A,$EA,$4A,$4A,$02,$4A,$4A,$02,$02,$02,$4A,$02,$02,$02,$02
tile037 byte $3A,$04,$2A,$1D,$2C,$2C,$4D,$06,$3E,$5B,$1D,$3E,$3E,$4D,$3E,$3E
        byte $4A,$4B,$3B,$2D,$2D,$3E,$06,$3E,$04,$03,$3E,$07,$3E,$3E,$1D,$4C
        byte $02,$EA,$4B,$4D,$06,$3E,$5C,$5B,$9A,$5B,$3E,$3E,$3E,$4D,$03,$02
        byte $02,$02,$3B,$1D,$5D,$04,$7C,$9B,$03,$04,$5B,$5B,$5B,$03,$02,$02
        byte $02,$02,$5A,$8A,$04,$9B,$03,$5A,$9B,$7C,$9B,$9B,$5A,$02,$02,$02
        byte $02,$02,$02,$02,$03,$8B,$8A,$8A,$5B,$9B,$8B,$03,$02,$02,$02,$02
        byte $02,$02,$02,$02,$5A,$5A,$02,$4A,$9B,$03,$6A,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$9A,$9B,$7A,$02,$02,$02,$02,$02,$02
        byte $4B,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $2A,$03,$02,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4A,$7A,$7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$7A
        byte $4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$04
        byte $02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$8A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$6A,$02
tile038 byte $4E,$03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$3A,$4A,$4A
        byte $03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$3A,$02,$02,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$4A,$02,$4A,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$4A,$02,$02,$3A
        byte $02,$02,$02,$02,$02,$02,$02,$3A,$02,$3A,$02,$3A,$02,$02,$02,$6A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$3A,$02,$02,$3A,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$02,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$3A,$02,$02,$02,$4A,$4A,$02,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $5B,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$3A
        byte $7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
tile039 byte $2A,$03,$6A,$02,$6A,$4A,$3A,$6B,$4A,$4A,$6B,$6A,$6B,$6A,$6A,$6A
        byte $03,$03,$6A,$02,$02,$6A,$4A,$6B,$4A,$6B,$6A,$4A,$6A,$6B,$4A,$6B
        byte $03,$02,$02,$02,$02,$3A,$6B,$4A,$6B,$6A,$4A,$6B,$4A,$4A,$6B,$6A
        byte $03,$4A,$02,$02,$02,$4A,$6B,$4A,$3A,$6B,$4A,$6B,$6B,$4A,$6B,$4A
        byte $03,$02,$3A,$4A,$02,$6A,$3A,$6B,$6A,$6B,$4A,$6B,$4A,$6B,$3A,$6B
        byte $4A,$02,$3A,$02,$02,$02,$6B,$4A,$6B,$4A,$6B,$6A,$6B,$3A,$6B,$4A
        byte $6A,$02,$4A,$4A,$02,$4A,$3A,$6B,$6A,$6B,$6A,$6B,$4A,$6B,$4A,$6B
        byte $02,$02,$4A,$6A,$02,$6A,$5A,$6B,$6A,$6B,$6A,$6A,$6B,$6A,$6A,$6B
        byte $5A,$03,$4A,$03,$02,$6A,$6B,$5A,$6B,$4A,$6A,$6B,$5A,$6B,$6B,$7A
        byte $7A,$5A,$3A,$03,$02,$02,$4A,$6B,$7A,$6B,$6B,$7B,$7B,$7B,$7B,$6C
        byte $4A,$6A,$03,$03,$4A,$6A,$7B,$5B,$7C,$6C,$7C,$7C,$7C,$7D,$7D,$8C
        byte $4B,$3A,$03,$4C,$02,$6A,$6D,$7D,$7D,$8C,$7C,$7D,$6D,$7C,$7D,$6D
        byte $04,$2A,$3A,$1D,$3A,$02,$7C,$7C,$8B,$7B,$7B,$7B,$7B,$7B,$6C,$7B
        byte $04,$4B,$2A,$4D,$02,$6A,$6A,$6A,$6A,$6B,$6A,$7A,$7A,$7A,$8A,$7A
        byte $3B,$04,$3A,$1D,$02,$4A,$6A,$6A,$6A,$02,$6A,$6A,$6A,$6A,$6A,$6A
        byte $5B,$5C,$03,$5C,$02,$4A,$02,$02,$6A,$6A,$02,$6A,$6A,$6A,$6A,$6A
tile040 byte $7A,$7A,$7A,$7B,$7B,$7A,$6B,$7B,$8B,$7B,$7C,$7C,$03,$5B,$03,$04
        byte $7B,$7B,$7B,$7B,$8B,$6C,$8B,$7C,$7C,$7C,$7C,$5B,$4A,$5B,$04,$05
        byte $8B,$7B,$7B,$7B,$8B,$8B,$7C,$8B,$7C,$7C,$7C,$8B,$03,$5B,$DC,$5D
        byte $8B,$8B,$8B,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$5B,$03,$04,$05,$CE
        byte $7C,$7C,$8C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$8C,$7B,$5A,$5B,$AD,$9D
        byte $7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$8C,$6D,$8A,$03,$03,$04,$04
        byte $7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7B,$5A,$03,$8B,$03
        byte $7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7B,$03,$03,$03,$9A
        byte $8B,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$8B,$7C,$7C,$7B,$03,$7B,$03,$03
        byte $7C,$7C,$8B,$8B,$7C,$7C,$7C,$7C,$6C,$7B,$8B,$9B,$5A,$5A,$8A,$7A
        byte $7C,$7C,$8B,$8B,$8B,$7C,$7B,$7B,$7B,$7B,$6B,$5A,$5A,$03,$8A,$7A
        byte $7C,$7C,$6C,$8B,$6C,$8B,$7B,$6B,$6B,$7B,$7B,$7B,$7A,$5A,$5A,$5A
        byte $8B,$7C,$8B,$7C,$7C,$7C,$8B,$8B,$6C,$8B,$7C,$8B,$7A,$7A,$7A,$7A
        byte $6C,$8B,$6C,$8B,$6C,$8B,$7C,$8B,$7C,$8B,$7C,$7C,$5B,$6A,$6A,$5A
        byte $7C,$8B,$8B,$7C,$6C,$7B,$8B,$8B,$6C,$7B,$6C,$7C,$7B,$5A,$02,$7A
        byte $7C,$8B,$7C,$8C,$7C,$8C,$8C,$7D,$7C,$8B,$8B,$7C,$7C,$8A,$7A,$5A
tile041 byte $04,$04,$5C,$4A,$02,$7A,$02,$02,$02,$02,$02,$02,$02,$BB,$07,$07
        byte $04,$5B,$4B,$4A,$6A,$4A,$02,$02,$02,$02,$02,$02,$02,$CA,$BC,$07
        byte $04,$1D,$5B,$5A,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$CA,$9C
        byte $07,$5E,$4A,$02,$04,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$BC
        byte $8E,$CD,$3A,$6A,$03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$BA
        byte $04,$04,$4A,$02,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$04
        byte $04,$04,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$AD
        byte $03,$04,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $7A,$03,$4A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $7A,$03,$03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $7A,$5A,$5A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $7A,$8A,$5A,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$6A,$9A,$5A,$02,$02,$02,$02,$02,$02,$02,$03,$02,$02,$02,$02
        byte $5A,$8A,$03,$7A,$02,$02,$02,$02,$02,$02,$7A,$5B,$5B,$5B,$03,$03
        byte $7A,$7A,$5A,$8A,$02,$02,$02,$02,$02,$7A,$8A,$03,$04,$05,$5B,$04
        byte $02,$7A,$5A,$5A,$6A,$02,$02,$02,$02,$02,$7A,$03,$03,$03,$9A,$9B
tile042 byte $BC,$BB,$AC,$8C,$8C,$8C,$07,$9D,$07,$9D,$07,$07,$07,$07,$07,$07
        byte $BC,$AC,$AC,$8C,$8C,$8C,$8C,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $BC,$BC,$AC,$8C,$8C,$8C,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $9D,$BB,$AC,$8C,$8C,$8C,$8C,$07,$07,$07,$07,$07,$07,$07,$07,$07
        byte $BC,$BC,$AC,$AC,$8C,$8C,$8C,$8C,$8C,$8C,$07,$07,$07,$07,$07,$07
        byte $9C,$BB,$BB,$BB,$BB,$BC,$AC,$AC,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$AD
        byte $04,$9B,$AC,$BB,$BB,$BB,$BB,$BB,$BB,$BB,$BB,$BB,$BB,$AC,$9D,$AE
        byte $9A,$8A,$04,$BA,$BA,$BA,$BB,$BB,$BA,$BA,$BA,$BA,$BB,$AC,$9D,$BC
        byte $02,$02,$03,$8A,$8B,$BA,$AA,$AA,$BA,$8A,$8A,$8A,$9C,$9C,$9B,$BC
        byte $02,$02,$03,$5A,$04,$AA,$AA,$AA,$AA,$02,$8A,$AA,$9B,$04,$04,$9B
        byte $02,$02,$9B,$03,$9B,$7A,$9A,$AA,$AA,$BA,$9A,$9A,$9A,$9B,$9B,$9B
        byte $02,$02,$03,$9A,$9B,$EA,$04,$04,$9B,$03,$03,$CA,$5A,$9A,$5A,$03
        byte $8A,$4A,$5B,$03,$04,$4A,$2A,$4B,$04,$04,$9B,$9A,$9A,$9A,$9A,$5A
        byte $CD,$5B,$DA,$9B,$5B,$02,$02,$8A,$8A,$8A,$5A,$7B,$03,$9A,$4A,$9B
        byte $8E,$5D,$5C,$03,$03,$4A,$03,$5B,$3A,$03,$03,$03,$03,$03,$5B,$04
        byte $8E,$CD,$06,$5A,$03,$04,$06,$9E,$6E,$05,$5E,$3E,$5E,$05,$5E,$BD
tile043 byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$9D,$07,$07,$AE
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$8C,$07,$8C,$07,$9D,$9D
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$8C,$8C,$8C
        byte $07,$07,$07,$07,$07,$07,$07,$07,$07,$07,$8C,$07,$8C,$07,$8C,$8C
        byte $07,$07,$07,$07,$07,$07,$07,$8C,$07,$07,$07,$07,$8C,$8C,$8C,$8C
        byte $07,$07,$9E,$07,$07,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C
        byte $8C,$9C,$9C,$9D,$07,$AD,$8C,$AC,$AC,$AC,$AC,$AC,$BB,$BB,$BB,$BB
        byte $BC,$BC,$BC,$AC,$9C,$AE,$9D,$BC,$BC,$BB,$BB,$BB,$BB,$BB,$BB,$BB
        byte $9B,$BC,$9B,$AB,$AB,$9D,$AE,$9D,$9C,$9B,$9A,$AA,$BA,$AB,$BA,$BA
        byte $9B,$7C,$9B,$04,$DA,$04,$AD,$AD,$9D,$04,$9B,$03,$03,$CA,$BA,$BA
        byte $5B,$9B,$9B,$7C,$9B,$9A,$04,$CC,$8D,$04,$BC,$03,$8B,$8A,$CA,$AA
        byte $9A,$03,$9A,$9A,$03,$03,$9B,$04,$04,$CC,$5B,$9B,$AA,$4A,$8A,$CA
        byte $03,$03,$03,$03,$9A,$9A,$9A,$9B,$5B,$04,$04,$5B,$EA,$5A,$02,$02
        byte $04,$DA,$03,$9B,$03,$9A,$03,$9B,$03,$04,$04,$04,$03,$03,$CA,$9A
        byte $5C,$9A,$9A,$5A,$9A,$03,$04,$04,$04,$9C,$9C,$BD,$04,$04,$03,$03
        byte $04,$5B,$03,$04,$5D,$04,$9B,$04,$04,$04,$9B,$9B,$04,$04,$04,$04
tile044 byte $9D,$9D,$9D,$BC,$BB,$BC,$BB,$AC,$DB,$DB,$BC,$07,$9D,$07,$07,$BC
        byte $9D,$9D,$9D,$BC,$BC,$BC,$CB,$BB,$DB,$AC,$AD,$AE,$07,$9D,$BC,$BA
        byte $9D,$9D,$BC,$AC,$BB,$BB,$CB,$BB,$CB,$CC,$9E,$07,$9D,$BB,$BA,$7A
        byte $8C,$9D,$9D,$BC,$BC,$BC,$CB,$BB,$CB,$AD,$07,$8C,$BB,$8A,$02,$8A
        byte $8C,$AC,$9C,$AC,$BB,$BB,$CB,$CB,$BC,$AE,$AC,$CA,$02,$02,$5A,$02
        byte $AC,$AC,$AC,$BC,$BB,$BB,$BB,$BB,$9D,$CC,$02,$02,$02,$02,$7A,$02
        byte $BB,$BB,$BB,$BB,$BB,$BB,$BA,$CA,$9A,$02,$02,$02,$02,$02,$02,$8A
        byte $BB,$BB,$BA,$BA,$BA,$BA,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $BA,$CA,$CA,$CA,$CA,$CA,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $CA,$CA,$BA,$02,$CA,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $CA,$CA,$CA,$CA,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$02,$4A,$7A
        byte $BA,$BA,$8A,$02,$CA,$CA,$02,$02,$02,$02,$02,$02,$02,$02,$5B,$02
        byte $9A,$8A,$CA,$CA,$BA,$02,$02,$02,$02,$02,$02,$02,$02,$02,$04,$5A
        byte $02,$8A,$8A,$8A,$02,$8A,$02,$02,$02,$02,$02,$02,$02,$02,$DA,$7A
        byte $04,$8A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$5B,$5A
        byte $7D,$7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$03,$4A
tile045 byte $BA,$CA,$CA,$CA,$02,$02,$02,$7A,$4A,$02,$02,$02,$5A,$04,$03,$EA
        byte $9A,$02,$7A,$02,$7A,$02,$02,$02,$CA,$02,$02,$02,$4A,$04,$4B,$5B
        byte $02,$8A,$8A,$02,$5A,$02,$02,$02,$02,$02,$02,$02,$04,$CC,$03,$4B
        byte $02,$02,$5A,$02,$8A,$02,$02,$02,$02,$8A,$02,$8A,$04,$04,$04,$4B
        byte $8A,$5A,$02,$8A,$02,$5A,$8A,$02,$02,$02,$02,$7A,$CD,$04,$05,$04
        byte $5A,$02,$02,$CA,$5A,$7A,$02,$02,$02,$8A,$02,$4A,$04,$CD,$CE,$5C
        byte $02,$8A,$5A,$5A,$02,$02,$02,$02,$02,$02,$02,$03,$CC,$6E,$07,$06
        byte $5A,$02,$02,$7A,$02,$02,$02,$02,$02,$8A,$02,$03,$04,$05,$07,$07
        byte $02,$4A,$02,$04,$06,$5B,$02,$02,$02,$02,$02,$03,$04,$EE,$07,$07
        byte $02,$5A,$03,$04,$EE,$9B,$02,$02,$02,$02,$02,$03,$04,$04,$06,$8E
        byte $02,$02,$9A,$02,$8A,$02,$02,$02,$02,$02,$CA,$9A,$04,$9C,$AE,$04
        byte $7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$AB,$04,$04,$5B,$03
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$CA,$03,$04,$03,$04,$AA
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$CA,$AA,$04,$9B,$03,$4A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$CA,$8A,$9B,$5B,$03,$8A
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$03,$04,$03,$03,$5A
tile046 byte $3A,$4A,$4A,$4A,$4A,$4A,$4A,$4A,$4A,$3A,$02,$02,$6A,$02,$02,$02
        byte $03,$03,$3A,$EA,$4A,$03,$4A,$4A,$02,$02,$02,$4A,$4A,$02,$02,$4A
        byte $EA,$4B,$3A,$03,$3A,$EA,$03,$4A,$4A,$02,$02,$3A,$02,$02,$02,$4A
        byte $5B,$4B,$EA,$5B,$03,$5B,$EA,$5A,$4A,$02,$4A,$4A,$03,$02,$4A,$02
        byte $04,$04,$5B,$03,$5B,$04,$5A,$5A,$03,$02,$02,$4A,$5B,$02,$02,$6A
        byte $CD,$1D,$04,$4B,$4B,$03,$4A,$4A,$03,$02,$4A,$02,$4A,$02,$02,$6A
        byte $07,$BE,$CE,$CC,$04,$03,$5A,$9A,$4A,$02,$4B,$4A,$02,$02,$02,$02
        byte $07,$8E,$05,$04,$5C,$03,$4A,$03,$5A,$02,$4A,$4B,$03,$3A,$2A,$03
        byte $07,$06,$8D,$04,$04,$03,$5A,$4A,$6A,$02,$02,$02,$3B,$4E,$4D,$4A
        byte $4E,$CD,$04,$04,$03,$5A,$5A,$03,$02,$02,$6A,$02,$02,$4D,$4B,$02
        byte $AD,$04,$4B,$03,$04,$03,$7A,$4A,$02,$02,$02,$02,$4A,$5A,$6A,$03
        byte $5C,$03,$9B,$5B,$03,$4A,$5A,$4A,$02,$02,$4A,$03,$3A,$4A,$4A,$3B
        byte $03,$4A,$03,$03,$9A,$4A,$02,$5A,$02,$02,$4A,$02,$02,$02,$4A,$3B
        byte $03,$8A,$8A,$5A,$03,$5A,$5A,$7A,$02,$02,$02,$02,$02,$02,$2A,$03
        byte $03,$7A,$5A,$4A,$03,$8A,$5A,$02,$02,$02,$02,$02,$02,$3A,$03,$4C
        byte $03,$7A,$5A,$4A,$4A,$5A,$8A,$4A,$02,$02,$02,$4A,$02,$3A,$2A,$4C
tile047 byte $02,$7A,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$6A
        byte $02,$7A,$5A,$02,$02,$02,$02,$02,$02,$6A,$6A,$6A,$6A,$7A,$02,$6A
        byte $4A,$5B,$4A,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02
        byte $5A,$5A,$5A,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$02
        byte $6A,$02,$5A,$6A,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$6A,$02,$02
        byte $02,$02,$7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4A,$6A,$02,$4A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4C,$2A,$4B,$03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $4D,$4B,$04,$4B,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $04,$4C,$4B,$4B,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A
        byte $4C,$3B,$4B,$4B,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $3B,$2A,$04,$4B,$02,$02,$02,$5A,$6A,$02,$6A,$02,$02,$02,$02,$02
        byte $03,$2A,$4C,$4A,$02,$02,$02,$02,$6A,$02,$02,$02,$6A,$02,$6A,$02
tile048 byte $7A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $6A,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$6A
        byte $6A,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$6A,$02,$02,$6A,$02,$03
        byte $02,$02,$02,$02,$02,$02,$6A,$5A,$8A,$5A,$5A,$5A,$7B,$5A,$7A,$7B
        byte $02,$02,$02,$02,$6A,$03,$5B,$03,$5A,$7A,$6A,$6A,$6A,$7A,$5A,$6A
        byte $02,$6A,$02,$7A,$5A,$5A,$02,$02,$02,$02,$02,$02,$02,$02,$5A,$6A
        byte $02,$02,$5A,$7A,$02,$02,$02,$02,$02,$6A,$02,$6A,$6A,$6A,$5A,$6A
        byte $6A,$6A,$5A,$6A,$6A,$6A,$02,$6A,$02,$6A,$02,$6A,$02,$6A,$02,$6A
tile049 byte $03,$1D,$4C,$4C,$02,$5A,$6A,$6A,$02,$6A,$6A,$6A,$6A,$6A,$6A,$6A
        byte $2A,$4C,$2E,$2A,$4A,$4A,$02,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$02,$6A
        byte $4A,$3B,$4E,$3A,$3A,$4A,$6A,$02,$6A,$6A,$02,$6A,$02,$6A,$6A,$5A
        byte $02,$3B,$04,$3A,$03,$4A,$5A,$7A,$6A,$02,$6A,$6A,$6A,$6A,$6A,$7B
        byte $02,$3A,$2A,$3B,$03,$7B,$7A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$5A
        byte $02,$4A,$4B,$4B,$03,$7A,$6A,$6A,$02,$6A,$02,$6A,$02,$6A,$7B,$6A
        byte $02,$02,$03,$4B,$7A,$6A,$02,$6A,$6A,$6A,$6A,$6A,$6A,$7B,$5A,$6A
        byte $02,$4A,$5A,$7A,$6A,$6A,$6A,$6A,$02,$6A,$6A,$02,$6A,$03,$7A,$6A
        byte $02,$5A,$02,$02,$6A,$02,$02,$6A,$6A,$6A,$6A,$6A,$03,$7B,$6A,$6A
        byte $5A,$7A,$02,$6A,$02,$6A,$6A,$6A,$02,$6A,$6A,$5A,$5B,$5A,$6A,$6A
        byte $6A,$6A,$6A,$02,$6A,$6A,$02,$6A,$6A,$6A,$6A,$5B,$7B,$7A,$6A,$02
        byte $02,$02,$6A,$6A,$02,$6A,$6A,$6A,$6A,$6A,$03,$03,$7A,$6A,$6A,$6A
        byte $6A,$02,$6A,$6A,$02,$6A,$02,$6A,$6A,$7A,$5B,$7A,$6A,$6A,$6A,$6A
        byte $6A,$02,$6A,$02,$6A,$02,$6A,$6A,$6A,$5A,$03,$7A,$6A,$6A,$6A,$7B
        byte $02,$6A,$6A,$6A,$6A,$6A,$6A,$02,$6A,$03,$6A,$02,$7B,$03,$6A,$7B
        byte $6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$03,$7B,$6A,$6A,$7B,$6C,$7B,$7B
tile050 byte $8B,$7B,$7C,$7C,$8C,$7D,$7D,$8C,$7C,$8C,$7D,$7D,$8D,$8B,$02,$03
        byte $7B,$7B,$7C,$7C,$9D,$8C,$8C,$7C,$8C,$8C,$8C,$8C,$7D,$8C,$7A,$9A
        byte $8B,$7C,$7C,$7C,$7C,$8C,$7C,$8C,$7C,$7C,$8C,$7C,$6C,$6C,$8B,$6C
        byte $7C,$7C,$8C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$6C,$8B,$6C,$7B,$8B,$7D
        byte $8B,$8B,$8C,$8C,$8C,$7C,$7C,$8B,$7C,$7C,$6C,$8B,$6C,$8B,$7C,$7C
        byte $7C,$8C,$7C,$8C,$7C,$8C,$8C,$7C,$7C,$8C,$7C,$7C,$8C,$7C,$8C,$8C
        byte $7C,$8C,$8C,$7C,$8C,$8C,$8C,$8C,$8C,$8B,$7C,$7C,$8C,$7C,$7C,$7C
        byte $7C,$8C,$8C,$7C,$8C,$8C,$7C,$7C,$8B,$7C,$8B,$8B,$8C,$7C,$7C,$7C
        byte $8C,$8C,$7C,$8B,$7C,$8C,$7C,$8B,$6C,$7C,$8B,$6C,$7C,$7C,$7C,$8B
        byte $8B,$7C,$8B,$6C,$7C,$7C,$6C,$6C,$7C,$7C,$8B,$8B,$7C,$7C,$8B,$7C
        byte $6B,$7B,$6B,$7B,$7C,$8B,$6B,$7B,$7C,$6C,$6C,$6C,$8B,$7C,$7C,$8C
        byte $8A,$8B,$8B,$7B,$8B,$7C,$6B,$7B,$7B,$8B,$7B,$6B,$7C,$8C,$7C,$7C
        byte $8B,$7C,$7C,$7C,$7C,$7C,$6C,$8B,$7B,$7C,$7B,$6B,$6C,$8B,$7C,$7C
        byte $7C,$7C,$8C,$7C,$8B,$7C,$8B,$7C,$6C,$6C,$6C,$8B,$6B,$6C,$8B,$7C
        byte $7C,$7C,$7C,$7C,$7C,$7C,$7C,$8B,$8C,$7C,$7C,$8B,$7C,$7B,$8B,$7C
        byte $7C,$7C,$7C,$8B,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$6C,$7C,$7C,$6C,$7C
tile051 byte $7A,$02,$6A,$8A,$02,$02,$02,$02,$02,$02,$02,$8A,$7A,$02,$8A,$9B
        byte $5A,$8A,$02,$7A,$03,$6A,$02,$02,$02,$6A,$7A,$8A,$6A,$02,$6A,$7C
        byte $03,$7A,$7A,$6A,$04,$8B,$6A,$7A,$8A,$6C,$7A,$8B,$7C,$6C,$7C,$8C
        byte $7B,$8A,$7A,$7A,$7C,$8C,$7B,$7C,$7C,$7D,$7C,$7D,$7D,$8C,$8C,$8D
        byte $7C,$7C,$8B,$7C,$7D,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$7D
        byte $7C,$8C,$7C,$8C,$8C,$8C,$7D,$7C,$7C,$8C,$7C,$8C,$7C,$8C,$7C,$8C
        byte $8C,$7C,$8B,$8B,$7C,$7C,$8C,$7C,$7C,$7C,$7C,$7C,$7C,$8C,$8B,$7C
        byte $8C,$7C,$8B,$8B,$8C,$7C,$8B,$8C,$7C,$7C,$7C,$7C,$7C,$7C,$8B,$7C
        byte $7C,$7C,$8B,$6C,$8C,$7C,$7C,$8B,$8C,$8C,$7C,$8B,$7C,$7C,$7C,$8C
        byte $8C,$7C,$8B,$7C,$8C,$6C,$7C,$8B,$7C,$7C,$7C,$8B,$8C,$7C,$7C,$9D
        byte $8B,$6C,$6C,$6C,$7C,$7C,$7C,$6C,$8B,$7C,$8C,$7C,$7C,$7C,$8C,$9D
        byte $6C,$6C,$8B,$8B,$8B,$7C,$7C,$6C,$6C,$8B,$7C,$8C,$7C,$7C,$8C,$8C
        byte $7C,$6C,$8B,$7C,$6C,$7C,$8B,$8B,$7C,$7C,$7C,$7C,$8C,$8C,$8C,$7C
        byte $7C,$7C,$8C,$7C,$7C,$8C,$7C,$6C,$7C,$8C,$8C,$7C,$8C,$7C,$7C,$7C
        byte $8C,$8C,$7C,$8B,$7C,$8C,$6C,$7C,$7C,$7C,$8C,$7C,$8C,$7C,$7C,$7C
        byte $7C,$8B,$7C,$7C,$7C,$7C,$6B,$8B,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$8C
tile052 byte $9A,$9A,$9B,$5B,$9A,$9B,$AC,$9C,$9C,$9C,$AC,$9D,$AE,$AD,$AE,$AE
        byte $5B,$7B,$7B,$8B,$7A,$02,$8B,$9B,$7B,$7B,$8B,$AA,$9B,$8B,$9B,$9B
        byte $8C,$8C,$7D,$7C,$6C,$7C,$7D,$8C,$8B,$8C,$7C,$7C,$7C,$8C,$7D,$7D
        byte $8C,$8C,$7D,$8C,$8C,$7D,$8C,$7D,$7C,$8C,$7D,$8C,$7C,$8C,$8D,$7D
        byte $7C,$8C,$7D,$8C,$8C,$8C,$8C,$9D,$7C,$8C,$8C,$7C,$7C,$8C,$8C,$9D
        byte $8C,$8C,$8C,$7C,$7C,$7C,$7C,$8C,$7C,$8C,$8C,$7C,$7C,$8C,$8C,$8C
        byte $8C,$7C,$8C,$8C,$7C,$8C,$8C,$7D,$8C,$7C,$7C,$7C,$7C,$7C,$8C,$8C
        byte $7D,$8C,$8C,$8C,$7C,$8C,$8C,$8C,$7C,$8C,$7C,$8C,$7C,$7C,$7C,$8C
        byte $8C,$7C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$7C,$7C,$7C,$8C,$8C,$7C,$7C
        byte $7C,$8C,$8C,$8C,$8C,$7C,$7C,$7C,$8C,$8C,$9D,$7D,$8C,$7C,$7C,$7C
        byte $7C,$8C,$7C,$8C,$8C,$7C,$8C,$8C,$7C,$8C,$8C,$8C,$9D,$7C,$8B,$7C
        byte $8C,$7C,$8C,$8C,$7C,$7C,$7C,$8C,$8C,$8C,$7C,$7C,$8C,$7C,$7C,$7C
        byte $8C,$7C,$7C,$7C,$8C,$7C,$8B,$7C,$8C,$7C,$7C,$7C,$8C,$7C,$7C,$7C
        byte $7C,$7C,$7C,$7C,$8C,$7C,$7C,$7C,$7C,$7C,$6C,$7C,$7C,$8B,$7C,$7C
        byte $7C,$8B,$7C,$8C,$8C,$7C,$7C,$6C,$7C,$7C,$8B,$6C,$7C,$7C,$8B,$6C
        byte $7C,$7C,$7C,$8C,$8C,$7C,$7C,$7C,$8B,$8B,$6C,$8B,$7C,$7C,$6C,$8B
tile053 byte $04,$9B,$9E,$07,$07,$07,$07,$8E,$CC,$9B,$04,$6E,$8D,$04,$5B,$03
        byte $8C,$5B,$9A,$9B,$8C,$8C,$8C,$9E,$04,$4A,$9B,$9E,$AE,$AE,$05,$05
        byte $04,$8B,$8B,$8B,$8D,$8C,$8B,$7D,$AE,$03,$7A,$9C,$9A,$9B,$03,$03
        byte $AD,$8D,$8C,$8C,$AE,$7D,$7D,$7C,$8B,$7C,$7C,$8C,$7B,$5A,$9B,$04
        byte $7C,$7D,$8C,$7C,$8C,$8C,$8C,$7C,$8B,$7C,$9D,$6D,$7C,$8B,$8A,$7C
        byte $8C,$8C,$8C,$7C,$8C,$7C,$7C,$8C,$7C,$7C,$9D,$7C,$7C,$7C,$7B,$8B
        byte $7C,$7C,$7C,$7C,$8C,$7C,$8B,$7C,$8B,$7C,$8C,$7C,$7C,$8C,$7C,$7C
        byte $7C,$8C,$8C,$8C,$8C,$8B,$6C,$8C,$7C,$8B,$8B,$7C,$7C,$7C,$7C,$7C
        byte $8C,$7C,$8C,$7C,$7C,$8B,$7C,$8C,$7C,$7C,$7B,$7C,$8C,$8C,$8C,$8C
        byte $7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$8C,$7C,$7C,$7C,$7C,$7C,$7C
        byte $8C,$8C,$6C,$7C,$7C,$7C,$7C,$7C,$8B,$7C,$7C,$7C,$7C,$7C,$7C,$7C
        byte $6C,$8B,$7C,$7C,$7C,$8C,$7C,$7C,$7B,$8B,$6C,$7C,$8C,$8B,$7C,$7C
        byte $7C,$7C,$7C,$7C,$8C,$8C,$8C,$8C,$6C,$7C,$7C,$7C,$8B,$8C,$9D,$8C
        byte $7C,$7C,$8C,$7C,$8C,$7C,$8C,$6C,$8B,$7C,$8B,$7C,$7C,$7C,$7C,$7C
        byte $8C,$7C,$8C,$7C,$7C,$7C,$7C,$6C,$7C,$8B,$7C,$7C,$8B,$7C,$7C,$7C
        byte $7C,$7C,$7C,$7C,$7C,$7C,$7C,$7C,$8B,$7C,$7C,$7C,$6C,$7B,$7C,$7C
tile054 byte $5B,$5B,$02,$02,$7A,$7A,$02,$7A,$02,$7A,$02,$5A,$02,$02,$5B,$4A
        byte $04,$DA,$4A,$04,$04,$04,$04,$04,$04,$4B,$04,$04,$04,$04,$EB,$5A
        byte $9C,$5B,$8A,$CA,$9B,$9A,$9B,$AB,$AB,$BC,$CC,$AD,$8E,$8E,$9C,$7A
        byte $5B,$9A,$8A,$5A,$4B,$8A,$7A,$8A,$5A,$8A,$8A,$AA,$9B,$AA,$9A,$5A
        byte $8B,$04,$9C,$7C,$9C,$7B,$03,$6A,$8A,$7B,$8A,$9A,$7A,$7A,$03,$9A
        byte $8C,$7C,$7C,$7C,$8C,$7C,$7D,$8C,$7C,$6D,$8C,$7C,$8B,$8B,$7C,$8B
        byte $7D,$8C,$7D,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$8C,$7C,$7C,$7C,$8C,$8C
        byte $8C,$7C,$8C,$8C,$8C,$7C,$8B,$7C,$8C,$7D,$8C,$7C,$7C,$7C,$8C,$8C
        byte $8C,$8C,$7C,$8C,$8C,$7C,$8B,$8C,$8C,$8C,$7C,$7C,$7C,$7C,$8C,$7C
        byte $7C,$7C,$8C,$7C,$8C,$8C,$8C,$8C,$8C,$6C,$7C,$8B,$7C,$7C,$7C,$7C
        byte $7C,$8C,$8C,$7C,$7C,$7C,$8B,$7C,$7C,$8B,$8C,$6C,$8B,$8B,$7C,$7C
        byte $7C,$8C,$8C,$7C,$8C,$8C,$8B,$7C,$7C,$7C,$8C,$6C,$8B,$6C,$8B,$8B
        byte $7C,$7C,$8C,$8C,$8C,$7C,$7C,$7C,$7C,$7C,$7C,$8B,$7C,$8B,$6C,$8B
        byte $7C,$8B,$7C,$8C,$7C,$7C,$7C,$7C,$8B,$8B,$8B,$7C,$8B,$7C,$8B,$8B
        byte $8C,$8B,$7C,$7C,$7C,$8B,$6C,$7C,$6C,$6C,$7B,$7B,$7B,$8B,$7C,$8B
        byte $8B,$6C,$7C,$7C,$7C,$8B,$8B,$8B,$7B,$7B,$7B,$7B,$8B,$8B,$7C,$7C
tile055 byte $02,$02,$02,$02,$6A,$02,$02,$02,$4A,$8A,$EA,$9A,$04,$9B,$4A,$02
        byte $02,$5A,$4A,$4A,$5B,$4A,$02,$02,$5A,$02,$02,$02,$9B,$03,$4A,$CA
        byte $02,$5C,$04,$EA,$8E,$04,$02,$02,$02,$02,$02,$7A,$5B,$04,$5A,$7A
        byte $02,$9A,$03,$9A,$04,$03,$02,$02,$02,$02,$02,$7A,$9A,$5A,$8A,$02
        byte $02,$02,$02,$02,$02,$7A,$02,$02,$02,$6A,$02,$02,$02,$5A,$02,$4A
        byte $02,$7B,$8B,$8B,$7B,$8A,$7A,$7A,$7A,$8A,$02,$02,$02,$8A,$CA,$8A
        byte $6C,$8B,$9D,$8C,$7C,$8B,$8B,$8B,$6C,$8B,$6A,$7B,$7A,$8A,$6A,$02
        byte $7C,$7C,$7C,$7C,$8B,$6C,$8B,$8B,$7C,$7C,$7C,$7C,$8B,$7C,$5A,$8A
        byte $7C,$7C,$7C,$8B,$7B,$7C,$7C,$8D,$8C,$8C,$8C,$7C,$7C,$7C,$9A,$03
        byte $7C,$8C,$7C,$7C,$7C,$7C,$7D,$AD,$8C,$8C,$7C,$7C,$7C,$7B,$8A,$8A
        byte $8C,$8C,$7C,$8C,$8C,$8C,$9D,$8C,$7C,$7C,$7C,$7C,$6C,$8B,$6B,$8B
        byte $7C,$8C,$8C,$7C,$7C,$8C,$8C,$8C,$7C,$7C,$7C,$7C,$8B,$7B,$8B,$8B
        byte $7C,$7C,$7C,$8C,$7C,$7C,$7C,$8C,$8C,$7C,$8B,$8B,$7C,$6C,$7C,$7B
        byte $7C,$7C,$7C,$7C,$7C,$7C,$8C,$7C,$7C,$7C,$8B,$6C,$7C,$8B,$7C,$8B
        byte $6C,$8C,$7C,$7C,$8B,$7C,$8B,$8B,$8C,$9D,$7C,$8B,$8B,$6C,$7C,$7C
        byte $7C,$7C,$8C,$8C,$7C,$7C,$8B,$7C,$7C,$8C,$8C,$8C,$8B,$7C,$8C,$7C
tile056 byte $5A,$8A,$02,$7A,$8A,$5A,$5A,$5A,$02,$02,$02,$2A,$02,$4A,$2A,$1D
        byte $03,$02,$5A,$7A,$EA,$03,$03,$02,$7A,$02,$4A,$3B,$04,$2A,$04,$4B
        byte $7A,$5A,$02,$5A,$5A,$03,$03,$8A,$02,$02,$02,$5C,$4B,$4B,$4C,$3B
        byte $02,$5A,$02,$02,$8A,$03,$8A,$02,$02,$02,$02,$3B,$4C,$2D,$4C,$3B
        byte $02,$8A,$02,$02,$02,$4A,$5A,$7A,$02,$02,$02,$3A,$06,$4D,$2B,$4C
        byte $02,$02,$02,$02,$02,$02,$8A,$02,$02,$02,$02,$02,$2A,$4C,$3D,$2E
        byte $02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$03,$2E,$4C
        byte $7A,$02,$02,$02,$02,$02,$7A,$02,$02,$02,$02,$02,$6A,$4A,$02,$02
        byte $02,$7A,$02,$7A,$02,$02,$02,$02,$02,$02,$02,$7A,$02,$02,$3A,$4A
        byte $7A,$02,$7A,$7A,$02,$02,$02,$7A,$02,$02,$6A,$8A,$7B,$5A,$7B,$7B
        byte $8A,$7B,$02,$7A,$7B,$7B,$7A,$7B,$8B,$7C,$7B,$6C,$7B,$8B,$6C,$7C
        byte $8B,$8B,$8B,$8B,$7C,$8B,$6C,$8B,$7C,$7C,$8B,$7C,$6C,$8B,$8B,$8B
        byte $6C,$6B,$7B,$7B,$6B,$8B,$7C,$6C,$7C,$7C,$6C,$8B,$8B,$6C,$8B,$7B
        byte $7C,$7C,$7C,$7C,$8B,$7C,$7C,$8B,$7C,$7C,$8B,$6C,$6C,$7B,$8B,$6B
        byte $7C,$8C,$8C,$7C,$8C,$7C,$7C,$8B,$6C,$6C,$6C,$7B,$7B,$7B,$6A,$7B
        byte $8C,$8C,$8C,$7C,$7C,$8B,$7C,$6C,$8B,$8B,$7B,$7A,$7A,$6A,$6A,$6A
tile057 byte $3A,$4B,$5C,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$02,$02,$6A
        byte $3A,$04,$03,$02,$02,$02,$02,$6A,$02,$6A,$02,$02,$6A,$02,$6A,$02
        byte $3B,$4C,$3A,$02,$02,$02,$6A,$02,$02,$02,$02,$6A,$02,$6A,$02,$6A
        byte $4C,$4B,$02,$02,$02,$02,$02,$6A,$02,$6A,$02,$02,$02,$02,$02,$02
        byte $3D,$03,$02,$02,$02,$02,$02,$02,$02,$02,$02,$6A,$02,$02,$6A,$02
        byte $4B,$3A,$02,$02,$6A,$02,$6A,$02,$6A,$02,$02,$6A,$02,$02,$02,$6A
        byte $3A,$02,$02,$6A,$02,$02,$6A,$02,$6A,$7A,$6B,$6A,$02,$6A,$6A,$6A
        byte $02,$4A,$02,$6A,$02,$6A,$6A,$6A,$6A,$6C,$8B,$7B,$7B,$7B,$6B,$7B
        byte $6A,$02,$6A,$6A,$6A,$7B,$8B,$7B,$8B,$6C,$8B,$6B,$8B,$6C,$8B,$7B
        byte $8A,$6A,$7A,$7B,$6B,$8B,$8B,$7B,$6B,$7B,$8B,$6B,$7B,$7B,$8B,$6C
        byte $7B,$7B,$7B,$7B,$7A,$6B,$7B,$6B,$8B,$7B,$6B,$7B,$7B,$8B,$6C,$8B
        byte $8B,$7B,$8B,$7B,$7B,$7B,$6B,$7B,$8B,$7B,$6A,$7A,$6A,$8B,$7B,$7B
        byte $6B,$6B,$8B,$7B,$6B,$7B,$8B,$7B,$7B,$7B,$6A,$7B,$6B,$6A,$7B,$7B
        byte $7A,$6A,$7B,$6B,$6A,$7B,$7B,$6B,$6B,$6A,$7A,$7A,$7A,$6A,$6A,$6A
        byte $7B,$6A,$6A,$6A,$7A,$7A,$7A,$7A,$6A,$6A,$7A,$8A,$8A,$6A,$6A,$6A
        byte $6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$7A,$6A,$6A,$6A
tile058 byte $02,$7A,$6A,$02,$02,$6A,$6A,$6A,$6A,$6A,$02,$6A,$02,$6A,$6A,$02
        byte $6A,$5A,$02,$6A,$6A,$6A,$02,$6A,$02,$6A,$6A,$6A,$6A,$7A,$7A,$6A
        byte $02,$6A,$6A,$6A,$02,$6A,$6A,$6A,$6A,$02,$7B,$03,$7B,$03,$6A,$6A
        byte $6A,$02,$02,$6A,$6A,$02,$6A,$6A,$6A,$7B,$5A,$6A,$7A,$6A,$02,$6A
        byte $02,$6A,$6A,$6A,$6A,$6A,$02,$6A,$7B,$7B,$6A,$02,$7A,$02,$02,$7A
        byte $6A,$6A,$7B,$6A,$7A,$7B,$6A,$7B,$7B,$8B,$7A,$7B,$7B,$7B,$6B,$7B
        byte $7A,$7B,$8C,$7B,$7C,$7C,$8B,$6C,$7C,$8C,$7C,$6C,$7C,$7C,$7C,$7B
        byte $7B,$7C,$7C,$8C,$7D,$8C,$8B,$8B,$8B,$7C,$7C,$7C,$7C,$7C,$8B,$6C
        byte $7C,$7C,$7C,$7C,$8C,$7C,$7C,$6C,$8B,$8B,$7C,$7C,$7C,$8B,$8B,$7C
        byte $8B,$7C,$7C,$7C,$7C,$7C,$8B,$6C,$8B,$6C,$8B,$7C,$6C,$8B,$7C,$8B
        byte $7B,$6C,$8B,$6C,$8B,$6C,$6C,$7B,$6C,$8B,$6C,$8B,$8B,$8B,$6C,$8B
        byte $7B,$7B,$7B,$8B,$6B,$7B,$8B,$7B,$7B,$6B,$7B,$6B,$6C,$6B,$7B,$7B
        byte $6A,$7B,$7A,$6B,$7A,$6A,$6B,$6B,$6A,$6A,$6A,$7A,$7A,$7A,$7A,$6B
        byte $7A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$7A,$6A,$7A,$6A,$6A,$6A,$6B,$7A
        byte $7A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$7A,$6A,$6A,$6A,$6A,$02,$6A
        byte $7A,$7A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A,$6A
tile059 byte $6A,$02,$6A,$6A,$6A,$02,$6A,$6A,$5B,$3A,$6A,$7B,$7C,$8B,$7B,$7C
        byte $6A,$6B,$7A,$5A,$5A,$6B,$3A,$03,$6B,$7B,$7B,$5B,$6C,$7C,$7B,$7C
        byte $03,$7A,$5A,$7B,$7B,$4A,$6A,$5B,$7B,$7B,$7C,$7C,$8B,$6C,$7B,$8B
        byte $6A,$6A,$7B,$7B,$5B,$6B,$6A,$7B,$5B,$6C,$8C,$7C,$7C,$7D,$8C,$7C
        byte $02,$7B,$7C,$6D,$7D,$7B,$6B,$7C,$8C,$7C,$8C,$7C,$8C,$8C,$7D,$7C
        byte $7A,$7B,$7C,$7D,$7C,$7C,$7C,$7C,$6C,$6C,$8C,$7C,$7C,$6C,$7C,$7D
        byte $6A,$6C,$7D,$8C,$7C,$8B,$7C,$7C,$7B,$7C,$7C,$7C,$7C,$7D,$7C,$8C
        byte $7B,$7C,$7C,$7C,$6C,$8B,$8B,$7B,$8B,$7C,$7C,$7C,$7C,$8C,$7C,$7C
        byte $8B,$8B,$7C,$8B,$8B,$6C,$8B,$6C,$7C,$8B,$8B,$8B,$6C,$7C,$8B,$8B
        byte $8B,$6C,$6C,$8B,$6B,$8B,$8B,$8B,$8B,$7C,$6C,$8B,$7B,$8B,$7B,$6B
        byte $6C,$8B,$8B,$6C,$7B,$7B,$6B,$7B,$6B,$6B,$7B,$6B,$7A,$6B,$6A,$7A
        byte $7B,$6C,$7B,$7B,$7B,$6B,$7B,$6B,$7B,$7A,$7A,$6B,$8A,$7A,$8A,$7B
        byte $7B,$7B,$6A,$7B,$7A,$7B,$7A,$7A,$6B,$7A,$6B,$6A,$7B,$7A,$7B,$7A
        byte $7A,$6A,$6B,$6A,$6A,$6A,$6A,$7A,$6A,$6A,$6A,$5A,$6A,$7A,$6A,$7A
        byte $7A,$7A,$7A,$7A,$7A,$6A,$6A,$6A,$7A,$6A,$6A,$6B,$6A,$6A,$6A,$7A
        byte $6A,$6A,$6B,$6B,$6A,$6A,$6A,$6A,$6B,$6A,$6A,$7A,$6A,$6A,$6A,$6A