''*****************************
''*  Hydra Asset Manager      *
''*  (C) Nurve Networks LLC.  *
''*****************************

CON

  _clkmode = xtal1 + pll8x
  _xinfreq = 10_000_000 + 0000
  _stack = ($5000 + 100) >> 2   'accomodate display memory and stack

  x_tiles = 16
  y_tiles = 12

  paramcount = 14       
  bitmap_base = $2000
  display_base = $5000

  CHAR_ROM_UPPER_IMAGE = $8000
  CHAR_ROM_LOWER_IMAGE = $8040
  CHAR_INDEX_01        = 24

  SERIAL_BUFFER_SIZE = 512  'rb - was 1024 512??
  EEPROM_BUFFER_SIZE = 256  'rb - was 32

  MODE_WAITING        = 0           
  MODE_FILE_ADDRESS   = 1
  MODE_FILE_SIZE      = 2
  MODE_FILE_BUFFER    = 3
  MODE_FILE_BUFFER_OK = 4
  MODE_FILE_CRC       = 5
  MODE_EEPROM_SEND    = 10
  MODE_ERROR_SEND          = 100
  MODE_ERROR_READ_TOO_MUCH = 101

  EEPROM_MEMORY_SIZE  = 128*1024

VAR

'  long  mousex, mousey

  long  tv_status     '0/1/2 = off/visible/invisible           read-only
  long  tv_enable     '0/? = off/on                            write-only
  long  tv_pins       '%ppmmm = pins                           write-only
  long  tv_mode       '%ccinp = chroma,interlace,ntsc/pal,swap write-only
  long  tv_screen     'pointer to screen (words)               write-only
  long  tv_colors     'pointer to colors (longs)               write-only               
  long  tv_hc         'horizontal cells                        write-only
  long  tv_vc         'vertical cells                          write-only
  long  tv_hx         'horizontal cell expansion               write-only
  long  tv_vx         'vertical cell expansion                 write-only
  long  tv_ho         'horizontal offset                       write-only
  long  tv_vo         'vertical offset                         write-only
  long  tv_broadcast  'broadcast frequency (Hz)                write-only
  long  tv_auralcog   'aural fm cog                            write-only

  word  screen[x_tiles * y_tiles]
  long  colors[64]

  long  serial_rx
  long  serial_rxidx
  long  serial_tx
  long  serial_txidx
  long  serial_rxbuf
  long  serial_rxsize
  long  serial_txbuf
  long  serial_txsize

  byte serial_rx_queue[1024]      ' at 11.52kbps - 192 bytes per frame. holds for 5.33 frames.
  byte serial_rx_buffer[1024]

  byte eeprom_tx_buffer[EEPROM_BUFFER_SIZE]
  byte eeprom_rx_buffer[EEPROM_BUFFER_SIZE]
  
'  word  map_data[16*16]
'  long  old_s
'  long  old_r
'  long  key_s
'  long  key_r


  byte  rx_size
'  byte  drawBufferTimer
  byte  receivedAddress

  byte  external_string[32]
  byte  temp_serial_rx[32]

  long  rx_size_history[4]
'  byte  rx_size_history_index
  byte sbuffer[32]

  long readBytes
  byte addressBuffer[4]

  long filesupersize

  long bufferSize

  long eepromOffset

  long bufferCRC

  long eepromWriteAddress
  long eepromWriteData
  'byte eepromTestData[16]

  long memorySize 
  
OBJ

  tv        : "tv_drv_010.spin"           'TV Driver  
  graphics  : "graphics_drv_010.spin"     'Graphics Driver
  eeprom    : "NS_eeprom_drv_011.spin"    'EEPROM Driver
  serial    : "copio_drv_001.spin"        'Serial COM Driver
 
PUB start      | i, j, k, kk, dx, dy, pp, pq, rr, numx, numchr

  'start tv
  longmove(@tv_status, @tvparams, paramcount)
  tv_screen := @screen
  tv_colors := @colors
  tv.start(@tv_status)

  'init colors
  repeat i from 0 to 64
    colors[i] := $00001010 * (i+4) & $F + $2B060C02

 'init tile screen
  repeat dx from 0 to tv_hc - 1
    repeat dy from 0 to tv_vc - 1
      screen[dy * tv_hc + dx] := display_base >> 6 + dy + dx * tv_vc + ((dy & $3F) << 10)

  'start and setup graphics
  graphics.start
  graphics.setup(16, 12, 128, 96, display_base)

  ' start serial engine
  serial.start(@serial_rx, 31, 30, 115200)
  serial.receive_circular(@serial_rx_queue, 1024) ' Setup circular buffer for receive queue. (should be sufficient for 2/60th's of baud rate or largest packet size *2 i.e. 260)

  'start eeprom driver
  eeprom.start(28, 29, 0)

  'Test reading from EEPROM.  
  eeprom.Read(@external_string, $8000, 32)
  repeat until eeprom.IsDone

  eeprom_tx_buffer[0] := 0

  repeat

'      repeat while tv_status == 1
'      repeat while tv_status == 2

      'clear bitmap
      graphics.clear
      graphics.colorwidth(3,14)
      graphics.textmode(1,1,6,4) ' 4 is horizontal center
      graphics.colorwidth(2,0)

      ' check to make sure that rx_size isn't greater than SERIAL_BUFFER_SIZE
      if (rx_size > SERIAL_BUFFER_SIZE)
         driverMode := MODE_ERROR_READ_TOO_MUCH  
      
      if (driverMode == MODE_WAITING)
         graphics.text(0, -10, string("waiting"))
         graphics.text(0, 30, @external_string)

         rx_size := serial.receive_queue(-1,-1)
         if (rx_size => 4)

            ' Shouldn't rx_size just be 4 ?         
            serial.receive_queue(@serial_rx_buffer, rx_size)
            graphics.text(-20,80,@serial_rx_buffer)
                     
            if (serial_rx_buffer[0] == fileString[0])
               serial.send(@fileString, 4)

               ' Now we have to wait for the server to validate the data.
               repeat
                  rx_size := serial.receive_queue(-1,-1)

                  if (rx_size => 2)
                     serial.receive_queue(@serial_rx_buffer, rx_size)
                     graphics.text(-20,80,@serial_rx_buffer)

                     if (serial_rx_buffer[0] == okString[0])
                        driverMode := MODE_FILE_ADDRESS
                     quit                        
                     
            elseif ( (serial_rx_buffer[0] == eepromDownloadString[0]) )
               ' Init starting EEPROM read offset before we start reading.
               eepromOffset := 0
               driverMode := MODE_EEPROM_SEND
             
      elseif (driverMode == MODE_FILE_ADDRESS)
         graphics.text(0, 30, string("address"))

         rx_size := serial.receive_queue(-1,-1)
         if (rx_size => 4)
         
            serial.receive_queue(@serial_rx_buffer, rx_size)
            graphics.text(-20,80,@serial_rx_buffer)

            eepromAddress := long[@serial_rx_buffer]                        
            serial.send(@eepromAddress, 4)

            ' Now we have to wait for the server to validate the data.
            repeat
               rx_size := serial.receive_queue(-1,-1)

               if (rx_size => 2)
                  serial.receive_queue(@serial_rx_buffer, rx_size)
                  graphics.text(-20,80,@serial_rx_buffer)

                  if (serial_rx_buffer[0] == okString[0])
                     driverMode := MODE_FILE_SIZE
                  quit                        
 
      elseif (driverMode == MODE_FILE_SIZE)
         graphics.text(0, 30, string("filesize"))

         rx_size := serial.receive_queue(-1,-1)
         if (rx_size => 4)

            serial.receive_queue(@serial_rx_buffer, 4)
            graphics.text(-20,80,@serial_rx_buffer)
            
            filesupersize := long[@serial_rx_buffer]

            serial.send(@filesupersize, 4)
            
            ' Now we have to wait for the server to validate the data.
            repeat
               rx_size := serial.receive_queue(-1,-1)

               if (rx_size => 2)
                  serial.receive_queue(@serial_rx_buffer, 2)
                  graphics.text(-20,80,@serial_rx_buffer)

                  if (serial_rx_buffer[0] == okString[0])
                     driverMode := MODE_FILE_BUFFER
                  quit                        

      elseif (driverMode == MODE_FILE_BUFFER)
         graphics.text(0, 30, string("buffer"))

         bufferSize := ReadBufferToEEPROM(eepromAddress)
         ' Offset eeprom address so the next buffer's worth goes into the correct location.
         eepromAddress += bufferSize
         filesupersize -= bufferSize

         if (filesupersize == 0)
            driverMode := MODE_WAITING

      elseif (driverMode == MODE_EEPROM_SEND)
         graphics.text(0, 30, string("eeprom"))

         repeat i from 0 to ((EEPROM_MEMORY_SIZE / 128) - 1) 

            eeprom.Read(@eeprom_rx_buffer, eepromOffset, 128)
            repeat until eeprom.IsDone
               graphics.text(40, 40, string("reading"))
            eepromOffset += 128   

            ' Now, send what we received from the eeprom read back to the PC   
            if ( serial.send(@eeprom_rx_buffer, 128) == false )
               driverMode := MODE_ERROR_SEND
            else
               ' Now we have to wait for the server to validate the data.
               repeat
                  rx_size := serial.receive_queue(-1,-1)

                  if (rx_size => 2)
                     serial.receive_queue(@serial_rx_buffer, rx_size)
                     graphics.text(-20,80,@serial_rx_buffer)

                     if (serial_rx_buffer[0] == okString[0])
                        quit   
               
         ' end repeat
         driverMode := MODE_WAITING      
         
      elseif (driverMode == MODE_ERROR_SEND)
         graphics.text(0, 30, string("send error"))

      elseif (driverMode == MODE_ERROR_READ_TOO_MUCH)
         graphics.text(0, 30, string("read too much"))
         
      screen[128] := CONSTANT((CHAR_ROM_UPPER_IMAGE>>6)+CHAR_INDEX_01*2)
      
  'end repeat

PUB ClearMemory | i

   ' Setup a buffer with nothing but zeros.
   repeat i from 0 to 511
      eeprom_tx_buffer[i] := 0

   ' Keep writing the zeroed out buffer to eeprom memory   
   repeat i from 0 to (128*1024/512)
      eeprom.Write(@eeprom_tx_buffer, i*512, 512)
      repeat until eeprom.IsDone
   
PUB MemoryWriteTest | i

'  repeat i from 0 to 511
'     eeprom_tx_buffer[i]

   repeat i from 0 to (128*1024/4)
'      eepromWriteAddress += 8*1024
      eepromWriteData := i*4

      ' Write a 1 into our test location.   
      eeprom.Write(@eepromWriteData, i*4, 4)
      repeat until eeprom.IsDone


PUB GetMemorySize  

   eepromWriteAddress := 0
   eepromWriteData    := 15

   eeprom.Write(@eepromWriteData, eepromWriteAddress, 4)
   repeat until eeprom.IsDone

   eeprom.Read(@eepromWriteData, eepromWriteAddress, 4)
   repeat until eeprom.IsDone

   if (eepromWriteData <> 15)
      return 0            

   'rb - TODO - fill in the logic.
   '  One idea is to keep writing at 8k boundaries and see where it stops working
   '  or overwrites a previous value due to mirroring.   Was going to just watch address 0
   '  but I'm not sure if I can guarantee that the mirroring will always work that way.
   repeat

      eepromWriteAddress += 8*1024
      eepromWriteData := 1

      ' Write a 1 into our test location.   
      eeprom.Write(@eepromWriteData, eepromWriteAddress, 4)
      repeat until eeprom.IsDone

      ' Read back from our write location.
      eeprom.Read(@eepromWriteData, eepromWriteAddress, 4)
      repeat until eeprom.IsDone

      ' Verify we got the same value back.
      if (eepromWriteData <> 1)
         return eepromWriteAddress
      ' If we did get the correct value back, verify that we haven't overwritten
      ' our value at address 0 due to mirroring.   
      else
         eeprom.Read(@eepromWriteData, 0, 4)
         repeat until eeprom.IsDone

         if (eepromWriteData <> 15)
            return eepromWriteAddress
            
   'return (128 * 1024)

PUB ReadBufferToEEPROM(eeprom_address) : buffer_size | i

   repeat
      ' Wait until we have 4 bytes.  It's the size of the buffer we're going to read in.
      rx_size := 0
      repeat until (rx_size => 4)
         rx_size := serial.receive_queue(-1,-1)
                  
      ' We received some data from the server.
      serial.receive_queue(@serial_rx_buffer, 4)
      buffer_size := long[@serial_rx_buffer]
      
      'rb - Check for False return.
      serial.send(@buffer_size, 4)

      ' Wait until we have 2 bytes.  It's our success code from the server.
      rx_size := 0
      repeat until (rx_size => 2)
         graphics.text(0, 20, string("W F ACK - buffer size"))
         rx_size := serial.receive_queue(-1,-1)
      
      serial.receive_queue(@serial_rx_buffer, 2)
      if ((serial_rx_buffer[0] == okString[0]) and (serial_rx_buffer[1] == okString[1]))
         quit   

   repeat
      rx_size := 0
      repeat until (rx_size => buffer_size)
         graphics.text(0, -30, string("W F Buffer"))
         rx_size := serial.receive_queue(-1,-1)

      serial.receive_queue(@serial_rx_buffer, buffer_size)

      ' Write the data to the eeprom address that we received in the previous step.
      'rb - TODO - We need to check to make sure that bufferSize is not greater than EEPROM write buffer.
      eeprom.Write(@serial_rx_buffer, eeprom_address, buffer_size)
      repeat until eeprom.IsDone

      ' Read buffer back from EEPROM so we can verify correct data.
      eeprom.Read(@eeprom_rx_buffer, eeprom_address, buffer_size)
      repeat until eeprom.IsDone

      bufferCRC := 0
      repeat i from 0 to (buffer_size-1)
         bufferCRC += eeprom_rx_buffer[i]
         bufferCRC &= $FFFF
                  
      serial.send(@bufferCRC, 2)

      ' Wait until we have 2 bytes.  It's our success code from the server.
      rx_size := 0
      repeat until (rx_size => 2)
         graphics.text(0, -40, string("W F ACK - CRC"))
         rx_size := serial.receive_queue(-1,-1)
      
      serial.receive_queue(@serial_rx_buffer, 2)
      if ((serial_rx_buffer[0] == okString[0]) and (serial_rx_buffer[1] == okString[1]))
         quit

   return buffer_size      

PUB drawBit(x, y, bit)

'' To erase a bit, call drawBit with the "bit" parameter set to 2

  screen[( y   *X_TILES) + x] := bit<<10 + CONSTANT((CHAR_ROM_UPPER_IMAGE>>6)+CHAR_INDEX_01*2)
 ' screen[((y+1)*X_TILES) + x] := bit<<10 + CONSTANT((CHAR_ROM_LOWER_IMAGE>>6)+CHAR_INDEX_01*2)

PUB itoa(value, string_ptr)     | base, factor, i
' converts an integer into an ASCIIZ, up to 99_999x
' string_ptr points to target storage to store converted string

' 100,000's place
base := 100_000

repeat i from 6 to 2
  factor := value / base 
  byte[0][string_ptr++] := hex_table [ factor ]
  value -= factor*base
  base /= 10

' 1's position
byte[0][string_ptr++] := hex_table [ value ]

' NULL terminate
byte[0][string_ptr++] := 0
  
DAT

tvparams                long    0               'status
                        long    1               'enable
'                        long    %011_0001       'pins - wireless video
                        long    %011_0000       'pins - normal video 
                        long    %0000           'mode
                        long    0               'screen
                        long    0               'colors
                        long    x_tiles         'hc
                        long    y_tiles         'vc
                        long    10              'hx
                        long    1               'vx
                        long    0               'ho
                        long    0               'vo
                        long    60_000_000      '_xinfreq<<4  'broadcast
                        long    0               'auralcog

hamString               byte    "Hydra Asset Manager",0           'text
fileString              byte    "FILE",0                          'text
okString                byte    "OK"
noString                byte    "NO"
driverMode              byte    MODE_WAITING
eepromAddress           long    0 
hex_table               byte    "0123456789ABCDEF"
eepromDownloadString    byte    "DLEP"
                                     